!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.N. Lang                              |            !
!        | `---' | UFO date: 05/2018                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2018-10-15 15:53             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 1450
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: FFaV0 = 4
  integer, parameter :: FFaV1 = 5
  integer, parameter :: SVVS0 = 6
  integer, parameter :: VVS0 = 7
  integer, parameter :: UUaS0 = 8
  integer, parameter :: UUaV0 = 9
  integer, parameter :: SUUa0 = 10
  integer, parameter :: VVSS0 = 11
  integer, parameter :: UaSU0 = 12
  integer, parameter :: VFaF0 = 13
  integer, parameter :: VFaF1 = 14
  integer, parameter :: VVV0 = 15
  integer, parameter :: FSFa0 = 16
  integer, parameter :: FSFa1 = 17
  integer, parameter :: FSFa2 = 18
  integer, parameter :: VVVV0 = 19
  integer, parameter :: FaVF0 = 20
  integer, parameter :: FaVF1 = 21
  integer, parameter :: UaVU0 = 22
  integer, parameter :: FaF0 = 23
  integer, parameter :: FaF1 = 24
  integer, parameter :: VSVS0 = 25
  integer, parameter :: FVFa0 = 26
  integer, parameter :: FVFa1 = 27
  integer, parameter :: VUaU0 = 28
  integer, parameter :: USUa0 = 29
  integer, parameter :: VV0 = 30
  integer, parameter :: VV1 = 31
  integer, parameter :: VV2 = 32
  integer, parameter :: SVSV0 = 33
  integer, parameter :: FaFS0 = 34
  integer, parameter :: FaFS1 = 35
  integer, parameter :: FaFS2 = 36
  integer, parameter :: FaFV0 = 37
  integer, parameter :: FaFV1 = 38
  integer, parameter :: SSSS0 = 39
  integer, parameter :: VS0 = 40
  integer, parameter :: SFFa0 = 41
  integer, parameter :: SFFa1 = 42
  integer, parameter :: SFFa2 = 43
  integer, parameter :: VUUa0 = 44
  integer, parameter :: SFaF0 = 45
  integer, parameter :: SFaF1 = 46
  integer, parameter :: SFaF2 = 47
  integer, parameter :: SVV0 = 48
  integer, parameter :: FaSF0 = 49
  integer, parameter :: FaSF1 = 50
  integer, parameter :: FaSF2 = 51
  integer, parameter :: SVS0 = 52
  integer, parameter :: FFa0 = 53
  integer, parameter :: FFa1 = 54
  integer, parameter :: VSS0 = 55
  integer, parameter :: VSV0 = 56
  integer, parameter :: SS0 = 57
  integer, parameter :: SSVV0 = 58
  integer, parameter :: SSV0 = 59
  integer, parameter :: SV0 = 60
  integer, parameter :: SSS0 = 61
  integer, parameter :: UVUa0 = 62
  integer, parameter :: VSSV0 = 63
  integer, parameter :: UaUS0 = 64
  integer, parameter :: VFFa0 = 65
  integer, parameter :: VFFa1 = 66
  integer, parameter :: SUaU0 = 67
  integer, parameter :: UaUV0 = 68
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c2f = "i_*sq2/2"
  complex(dp), parameter :: c3 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c3f = "-i_*sq2/2"
  complex(dp), parameter :: c4 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c4f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c5 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c5f = "sq2/2"
  complex(dp), parameter :: c6 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c6f = "1/2"
  complex(dp), parameter :: c7 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c7f = "-1/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:68) :: lorentz_rank = (/0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0 &
                                             , 0, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1 &
                                             , -1, -1, 0, 1, 1, 1, 0, -1, -1, -&
                                             1, 0, 0, 0, 0, 0, 0, 0, -1, 1, 1, &
                                             1, 1, 1, 1, 1, 0, 1, 1, 1, 1, -1  &
                                             , -1, 1, 0, -1, 0, 1, -1, 0, 1, 0 &
                                             , 0, 1, 1, 0, 1/)
  integer, dimension(1:68) :: recola_base = (/5, 7, 9, 17, 15, -2, 2, 1, 161, 1&
                                            , -4, 1, 53, 58, 12, 21, 25, 27, - &
                                            11, 51, 57, 166, 0, 0, -3, 31, 35, &
                                            162, 1, 0, 0, 0, -14, 6, 10, 8, 16 &
                                            , 18, -1, 0, 23, 26, 28, 163, 43,  &
                                            46, 48, 13, 41, 47, 45, 3, 0, 0, 4 &
                                            , 14, 0, -12, 11, 0, 1, 165, -13, 1&
                                            , 33, 36, 1, 164/)
  integer, dimension(1:68) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     /)
  character(len=*), parameter :: model_timestamp = "Mon Oct 15 15:50:27 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id)
      integer, intent(in) :: P1, P2, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id)
      integer, intent(in) :: P1, P2, P3, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id)
      integer, intent(in) :: P1, P2, P3, P4, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      integer(kind=8) :: key
      integer :: address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      call dict(key, 2, address, found, id)
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl
      integer :: address
      integer :: key
      logical :: found

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(2897)

      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 819)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 628)
      call createCurrent(P_GPlus, P_b, P_tAnti, 594)
      call createCurrent(P_b, P_bAnti, P_g, 313)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 449)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 835)
      call createCurrent(P_WpPlus, P_tAnti, P_s, 350)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_H, 365)
      call createCurrent(P_WpMinus, P_dAnti, P_t, 593)
      call createCurrent(P_Z, P_GPlus, P_H, P_WMinus, 218)
      call createCurrent(P_GPlus, P_uAnti, P_s, 231)
      call createCurrent(P_H, P_WMinus, P_WPlus, 204)
      call createCurrent(P_WpPlus, P_s, P_cAnti, 100)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 579)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, 3)
      call createCurrent(P_s, P_sAnti, P_H, 1048)
      call createCurrent(P_cAnti, P_WpPlus, P_d, 793)
      call createCurrent(P_WpMinus, P_nu_e, P_ePlus, 44)
      call createCurrent(P_g, P_cAnti, P_c, 1238)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 126)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 691)
      call createCurrent(P_cAnti, P_g, P_u, 1389)
      call createCurrent(P_sAnti, P_g, P_s, 1177)
      call createCurrent(P_c, P_GMinus, P_dAnti, 601)
      call createCurrent(P_A, P_ePlus, P_eMinus, 269)
      call createCurrent(P_s, P_WpPlus, P_cAnti, 345)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, 884)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 865)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 1022)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_tauAnti, 378)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 308)
      call createCurrent(P_WMinus, P_dAnti, P_u, 782)
      call createCurrent(P_u, P_cAnti, P_g, 1448)
      call createCurrent(P_WPlus, P_WMinus, P_H, P_H, 197)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 759)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 942)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 1183)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 1109)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 495)
      call createCurrent(P_WMinus, P_H, P_Z, P_GPlus, 896)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_e, 233)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 804)
      call createCurrent(P_bAnti, P_b, P_g, 1249)
      call createCurrent(P_cAnti, P_Z, P_c, 735)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 500)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 937)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 1077)
      call createCurrent(P_g, P_u, P_tAnti, 1445)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 1117)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 39)
      call createCurrent(P_t, P_Z, P_tAnti, 558)
      call createCurrent(P_G0, P_dAnti, P_d, 50)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 910)
      call createCurrent(P_s, P_Z, P_sAnti, 351)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 92)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 272)
      call createCurrent(P_H, P_cAnti, P_c, 887)
      call createCurrent(P_H, P_H, P_GPlus, P_GMinus, 801)
      call createCurrent(P_GMinus, P_dAnti, P_u, 496)
      call createCurrent(P_H, P_sAnti, P_d, 966)
      call createCurrent(P_A, P_muPlus, P_muMinus, 1237)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 729)
      call createCurrent(P_H, P_Z, P_GMinus, P_WPlus, 318)
      call createCurrent(P_G0, P_uAnti, P_u, 333)
      call createCurrent(P_u, P_g, P_cAnti, 1419)
      call createCurrent(P_G0, P_c, P_cAnti, 1256)
      call createCurrent(P_s, P_uAnti, P_GPlus, 305)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 712)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 7)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 307)
      call createCurrent(P_c, P_g, P_tAnti, 1413)
      call createCurrent(P_uAnti, P_s, P_WpPlus, 695)
      call createCurrent(P_sAnti, P_WpMinus, P_u, 404)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 552)
      call createCurrent(P_dAnti, P_t, P_WpMinus, 1174)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 1101)
      call createCurrent(P_sAnti, P_s, P_H, 586)
      call createCurrent(P_A, P_H, P_GMinus, P_WPlus, 411)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 533)
      call createCurrent(P_Z, P_uAnti, P_u, 610)
      call createCurrent(P_H, P_muMinus, P_muPlus, 471)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_A, 424)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 74)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 277)
      call createCurrent(P_GPlus, P_H, P_GMinus, P_H, 926)
      call createCurrent(P_WMinus, P_GPlus, P_H, 929)
      call createCurrent(P_GPlus, P_H, P_H, P_GMinus, 387)
      call createCurrent(P_dAnti, P_g, P_d, 1112)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_e, 901)
      call createCurrent(P_c, P_cAnti, P_A, 1299)
      call createCurrent(P_tauMinus, P_nu_muAnti, P_WpPlus, 123)
      call createCurrent(P_H, P_dAnti, P_s, 917)
      call createCurrent(P_cAnti, P_GPlus, P_d, 112)
      call createCurrent(P_G0, P_sAnti, P_d, 259)
      call createCurrent(P_u, P_tAnti, P_g, 1438)
      call createCurrent(P_tAnti, P_t, P_A, 598)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 666)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 1032)
      call createCurrent(P_b, P_WpPlus, P_cAnti, 155)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_H, 732)
      call createCurrent(P_c, P_sAnti, P_WMinus, 615)
      call createCurrent(P_c, P_WpMinus, P_dAnti, 205)
      call createCurrent(P_A, P_d, P_dAnti, 1070)
      call createCurrent(P_dAnti, P_c, P_WMinus, 1258)
      call createCurrent(P_H, P_WPlus, P_WMinus, 1255)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 1211)
      call createCurrent(P_H, P_H, P_H, 733)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 278)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 1052)
      call createCurrent(P_d, P_WpPlus, P_tAnti, 800)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_A, 847)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 379)
      call createCurrent(P_uAnti, P_u, 1374)
      call createCurrent(P_WpMinus, P_bAnti, P_c, 1134)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_Z, 1218)
      call createCurrent(P_sAnti, P_A, P_s, 252)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 1244)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 45)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WpPlus, 302)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_muMinus, 57)
      call createCurrent(P_uAnti, P_WPlus, P_s, 1252)
      call createCurrent(P_d, P_H, P_sAnti, 180)
      call createCurrent(P_t, P_sAnti, P_WpMinus, 938)
      call createCurrent(P_uAnti, P_WpPlus, P_s, 1009)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 362)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 898)
      call createCurrent(P_uAnti, P_u, P_g, 678)
      call createCurrent(P_nu_e, P_WpMinus, P_muPlus, 384)
      call createCurrent(P_WpPlus, P_s, P_tAnti, 850)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 841)
      call createCurrent(P_nu_eAnti, P_muMinus, P_WpPlus, 94)
      call createCurrent(P_GMinus, P_H, P_A, P_WPlus, 175)
      call createCurrent(P_u, P_uAnti, 1347)
      call createCurrent(P_sAnti, P_H, P_s, 1053)
      call createCurrent(P_s, P_WpPlus, P_uAnti, 1006)
      call createCurrent(P_tAnti, P_t, P_Z, 1023)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 484)
      call createCurrent(P_dAnti, P_g, P_s, 1396)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 542)
      call createCurrent(P_sAnti, P_s, P_Z, 1292)
      call createCurrent(P_d, P_cAnti, P_GPlus, 1103)
      call createCurrent(P_G0, P_H, P_G0, 649)
      call createCurrent(P_WMinus, P_dAnti, P_c, 255)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 276)
      call createCurrent(P_A, P_H, P_WMinus, P_GPlus, 1287)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 945)
      call createCurrent(P_s, P_H, P_sAnti, 651)
      call createCurrent(P_cAnti, P_c, 1371)
      call createCurrent(P_c, P_cAnti, P_G0, 153)
      call createCurrent(P_WpPlus, P_cAnti, P_b, 686)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 1035)
      call createCurrent(P_sAnti, P_b, P_g, 1403)
      call createCurrent(P_c, P_sAnti, P_WpMinus, 534)
      call createCurrent(P_WMinus, P_H, P_WPlus, 724)
      call createCurrent(P_G0, P_tAnti, P_t, 919)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 745)
      call createCurrent(P_s, P_dAnti, P_G0, 1202)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_e, 1116)
      call createCurrent(P_s, P_GPlus, P_cAnti, 382)
      call createCurrent(P_cAnti, P_d, P_WPlus, 994)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 1090)
      call createCurrent(P_GPlus, P_WMinus, P_H, 928)
      call createCurrent(P_dAnti, P_d, P_g, 260)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 297)
      call createCurrent(P_g, P_s, P_dAnti, 1429)
      call createCurrent(P_c, P_cAnti, 1356)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_A, 440)
      call createCurrent(P_WpMinus, P_c, P_bAnti, 927)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 641)
      call createCurrent(P_GPlus, P_s, P_cAnti, 501)
      call createCurrent(P_A, P_H, P_GPlus, P_WMinus, 650)
      call createCurrent(P_uAnti, P_GPlus, P_d, 1164)
      call createCurrent(P_eMinus, P_nu_tauAnti, P_WpPlus, 43)
      call createCurrent(P_s, P_sAnti, P_g, 1033)
      call createCurrent(P_uAnti, P_Z, P_u, 394)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 1030)
      call createCurrent(P_ePlus, P_nu_e, P_WpMinus, 1219)
      call createCurrent(P_A, P_GPlus, P_H, P_WMinus, 132)
      call createCurrent(P_d, P_dAnti, 1360)
      call createCurrent(P_H, P_A, P_WMinus, P_GPlus, 1047)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 81)
      call createCurrent(P_H, P_G0, P_Z, 1228)
      call createCurrent(P_d, P_GPlus, P_cAnti, 1184)
      call createCurrent(P_uAnti, P_d, P_WpPlus, 133)
      call createCurrent(P_WpMinus, P_nu_tau, P_tauPlus, 858)
      call createCurrent(P_d, P_sAnti, P_H, 1081)
      call createCurrent(P_G0, P_d, P_dAnti, 1251)
      call createCurrent(P_bAnti, P_G0, P_b, 947)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 908)
      call createCurrent(P_H, P_Z, P_G0, 905)
      call createCurrent(P_ghZ, P_ghZAnti, P_H, 83)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_eMinus, 907)
      call createCurrent(P_bAnti, P_Z, P_b, 1098)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 984)
      call createCurrent(P_d, P_dAnti, P_A, 388)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 77)
      call createCurrent(P_s, P_GPlus, P_uAnti, 715)
      call createCurrent(P_tauPlus, P_nu_tau, P_WpMinus, 12)
      call createCurrent(P_H, P_muPlus, P_muMinus, 395)
      call createCurrent(P_WPlus, P_WMinus, 1339)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 167)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 85)
      call createCurrent(P_dAnti, P_WpMinus, P_u, 294)
      call createCurrent(P_c, P_dAnti, P_GMinus, 15)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_H, 1007)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 726)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_eAnti, 1187)
      call createCurrent(P_muPlus, P_A, P_muMinus, 810)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 540)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 1188)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 1200)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 777)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 931)
      call createCurrent(P_d, P_G0, P_dAnti, 656)
      call createCurrent(P_s, P_WPlus, P_cAnti, 570)
      call createCurrent(P_dAnti, P_WMinus, P_u, 144)
      call createCurrent(P_WpPlus, P_uAnti, P_d, 216)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 413)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 1316)
      call createCurrent(P_d, P_cAnti, P_WPlus, 29)
      call createCurrent(P_muPlus, P_nu_tau, P_WpMinus, 1140)
      call createCurrent(P_muPlus, P_nu_mu, P_WpMinus, 1050)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 1059)
      call createCurrent(P_u, P_dAnti, P_WpMinus, 1209)
      call createCurrent(P_A, P_s, P_sAnti, 405)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 70)
      call createCurrent(P_nu_e, P_ePlus, P_WpMinus, 728)
      call createCurrent(P_WMinus, P_H, P_GPlus, 1015)
      call createCurrent(P_H, P_d, P_sAnti, 370)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 965)
      call createCurrent(P_A, P_H, P_WPlus, P_GMinus, 340)
      call createCurrent(P_d, P_g, P_dAnti, 567)
      call createCurrent(P_g, P_t, P_tAnti, 1096)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 1264)
      call createCurrent(P_t, P_tAnti, 1361)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 56)
      call createCurrent(P_sAnti, P_WMinus, P_u, 634)
      call createCurrent(P_s, P_dAnti, P_g, 1449)
      call createCurrent(P_nu_mu, P_nu_muAnti, 1370)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 373)
      call createCurrent(P_GMinus, P_A, P_WPlus, 372)
      call createCurrent(P_c, P_cAnti, P_g, 457)
      call createCurrent(P_dAnti, P_d, P_A, 771)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_A, 258)
      call createCurrent(P_u, P_uAnti, P_Z, 577)
      call createCurrent(P_GPlus, P_H, P_Z, P_WMinus, 1054)
      call createCurrent(P_tauMinus, P_tauPlus, 1343)
      call createCurrent(P_t, P_bAnti, P_WMinus, 1119)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, 675)
      call createCurrent(P_uAnti, P_WpPlus, P_d, 311)
      call createCurrent(P_g, P_b, P_bAnti, 667)
      call createCurrent(P_A, P_b, P_bAnti, 699)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 164)
      call createCurrent(P_sAnti, P_d, P_g, 1407)
      call createCurrent(P_c, P_H, P_cAnti, 662)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 6)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 477)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 1102)
      call createCurrent(P_GMinus, P_u, P_sAnti, 950)
      call createCurrent(P_ePlus, P_eMinus, P_H, 814)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 148)
      call createCurrent(P_d, P_H, P_dAnti, 625)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 1300)
      call createCurrent(P_sAnti, P_s, P_G0, 1275)
      call createCurrent(P_WpMinus, P_sAnti, P_t, 107)
      call createCurrent(P_u, P_G0, P_uAnti, 893)
      call createCurrent(P_H, P_A, P_GMinus, P_WPlus, 331)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_tauAnti, 176)
      call createCurrent(P_G0, P_cAnti, P_c, 864)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, 1151)
      call createCurrent(P_H, P_t, P_tAnti, 391)
      call createCurrent(P_GMinus, P_WPlus, P_H, 446)
      call createCurrent(P_G0, P_sAnti, P_s, 903)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_tau, 921)
      call createCurrent(P_g, P_g, P_g, 985)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, 1234)
      call createCurrent(P_WPlus, P_A, P_WMinus, 538)
      call createCurrent(P_eMinus, P_ePlus, P_A, 1010)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_H, 371)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_tau, 1158)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 705)
      call createCurrent(P_g, P_tAnti, P_u, 1434)
      call createCurrent(P_d, P_GPlus, P_uAnti, 228)
      call createCurrent(P_H, P_Z, P_WMinus, P_GPlus, 41)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 698)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 682)
      call createCurrent(P_WMinus, P_Z, P_H, P_GPlus, 510)
      call createCurrent(P_c, P_dAnti, P_WpMinus, 1067)
      call createCurrent(P_WPlus, P_A, P_GMinus, 178)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_H, 410)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 1038)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 1330)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 158)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 977)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 319)
      call createCurrent(P_bAnti, P_WMinus, P_t, 96)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 1304)
      call createCurrent(P_WpMinus, P_dAnti, P_c, 560)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 663)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 717)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_H, 433)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 953)
      call createCurrent(P_nu_tau, P_tauPlus, P_WpMinus, 809)
      call createCurrent(P_d, P_WpPlus, P_cAnti, 168)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 834)
      call createCurrent(P_WpMinus, P_nu_e, P_muPlus, 693)
      call createCurrent(P_GMinus, P_WPlus, P_A, 182)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 402)
      call createCurrent(P_tauPlus, P_tauMinus, 1368)
      call createCurrent(P_c, P_Z, P_cAnti, 849)
      call createCurrent(P_H, P_b, P_bAnti, 976)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 1203)
      call createCurrent(P_WMinus, P_u, P_sAnti, 981)
      call createCurrent(P_g, P_g, 1341)
      call createCurrent(P_Z, P_Z, P_H, 137)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, 1000)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 2)
      call createCurrent(P_WPlus, P_GMinus, P_H, 507)
      call createCurrent(P_WMinus, P_H, P_H, P_WPlus, 47)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 328)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 247)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 746)
      call createCurrent(P_A, P_WMinus, P_H, P_GPlus, 385)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 608)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 1075)
      call createCurrent(P_u, P_uAnti, P_g, 1263)
      call createCurrent(P_nu_tauAnti, P_eMinus, P_WpPlus, 874)
      call createCurrent(P_nu_e, P_muPlus, P_WpMinus, 520)
      call createCurrent(P_GPlus, P_H, P_A, P_WMinus, 1259)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 270)
      call createCurrent(P_tauPlus, P_H, P_tauMinus, 214)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 869)
      call createCurrent(P_WPlus, P_GMinus, 1365)
      call createCurrent(P_tAnti, P_g, P_c, 1447)
      call createCurrent(P_u, P_g, P_uAnti, 1078)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 169)
      call createCurrent(P_dAnti, P_c, P_GMinus, 1281)
      call createCurrent(P_H, P_WPlus, P_GMinus, 817)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_muAnti, 293)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, 58)
      call createCurrent(P_s, P_tAnti, P_WpPlus, 535)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 281)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 983)
      call createCurrent(P_ePlus, P_eMinus, P_A, 274)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_Z, 637)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_eAnti, 343)
      call createCurrent(P_ghZAnti, P_H, P_ghZ, 210)
      call createCurrent(P_tauMinus, P_tauPlus, P_H, 1040)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 614)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 162)
      call createCurrent(P_H, P_Z, P_Z, P_H, 696)
      call createCurrent(P_H, P_GMinus, P_WPlus, 636)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 996)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 781)
      call createCurrent(P_nu_tau, P_WpMinus, P_tauPlus, 1127)
      call createCurrent(P_d, P_G0, P_sAnti, 238)
      call createCurrent(P_t, P_tAnti, P_A, 747)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_H, 571)
      call createCurrent(P_H, P_ghWpAnti, P_ghWp, 863)
      call createCurrent(P_H, P_tauPlus, P_tauMinus, 366)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 316)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 1182)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_A, 918)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 562)
      call createCurrent(P_t, P_tAnti, P_G0, 949)
      call createCurrent(P_dAnti, P_WpMinus, P_t, 645)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 325)
      call createCurrent(P_d, P_WPlus, P_uAnti, 990)
      call createCurrent(P_dAnti, P_u, P_GMinus, 768)
      call createCurrent(P_cAnti, P_s, P_WpPlus, 611)
      call createCurrent(P_nu_mu, P_ePlus, P_WpMinus, 664)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 681)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 1298)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 936)
      call createCurrent(P_GPlus, P_cAnti, P_d, 1071)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 88)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 312)
      call createCurrent(P_H, P_ghZAnti, P_ghZ, 549)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 246)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_Z, 1132)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 757)
      call createCurrent(P_u, P_dAnti, P_WMinus, 772)
      call createCurrent(P_tAnti, P_GPlus, P_b, 627)
      call createCurrent(P_s, P_A, P_sAnti, 78)
      call createCurrent(P_s, P_WpPlus, P_tAnti, 968)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 229)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 957)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_eMinus, 701)
      call createCurrent(P_G0, P_H, P_Z, 1170)
      call createCurrent(P_d, P_cAnti, P_WpPlus, 644)
      call createCurrent(P_H, P_H, P_WMinus, P_WPlus, 1018)
      call createCurrent(P_GMinus, P_dAnti, P_c, 1326)
      call createCurrent(P_GMinus, P_bAnti, P_t, 207)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_Z, 830)
      call createCurrent(P_cAnti, P_A, P_c, 1079)
      call createCurrent(P_g, P_g, P_H, 1383)
      call createCurrent(P_muPlus, P_muMinus, P_H, 22)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 689)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 503)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 1131)
      call createCurrent(P_bAnti, P_g, P_s, 1391)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 1250)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 1061)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 1036)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_H, 421)
      call createCurrent(P_muMinus, P_muPlus, 1345)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 142)
      call createCurrent(P_bAnti, P_b, P_G0, 551)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 1289)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 1223)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 1309)
      call createCurrent(P_muMinus, P_muPlus, P_A, 1327)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 1031)
      call createCurrent(P_WMinus, P_c, P_sAnti, 86)
      call createCurrent(P_g, P_uAnti, P_t, 1376)
      call createCurrent(P_sAnti, P_u, P_GMinus, 1020)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_A, 1336)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 1222)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 1083)
      call createCurrent(P_b, P_bAnti, P_G0, 17)
      call createCurrent(P_A, P_WPlus, P_WMinus, 825)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 335)
      call createCurrent(P_WPlus, P_Z, P_H, P_GMinus, 799)
      call createCurrent(P_sAnti, P_t, P_WpMinus, 428)
      call createCurrent(P_H, P_sAnti, P_s, 283)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 1173)
      call createCurrent(P_WpMinus, P_sAnti, P_u, 75)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 875)
      call createCurrent(P_A, P_GPlus, P_WMinus, 1153)
      call createCurrent(P_WpMinus, P_nu_mu, P_tauPlus, 1105)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 897)
      call createCurrent(P_s, P_cAnti, P_WPlus, 1143)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 714)
      call createCurrent(P_A, P_WMinus, P_WPlus, 1138)
      call createCurrent(P_H, P_WMinus, P_GPlus, 1062)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_mu, 237)
      call createCurrent(P_WpPlus, P_b, P_cAnti, 1181)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 959)
      call createCurrent(P_nu_eAnti, P_nu_e, 1351)
      call createCurrent(P_WPlus, P_b, P_tAnti, 1123)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 536)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 173)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 878)
      call createCurrent(P_G0, P_Z, 1363)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 739)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 1162)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 508)
      call createCurrent(P_WPlus, P_uAnti, P_s, 742)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 422)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 90)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 482)
      call createCurrent(P_G0, P_bAnti, P_b, 1120)
      call createCurrent(P_uAnti, P_b, P_WpPlus, 725)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 222)
      call createCurrent(P_sAnti, P_WpMinus, P_c, 1186)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, 358)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 397)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 120)
      call createCurrent(P_nu_muAnti, P_tauMinus, P_WpPlus, 250)
      call createCurrent(P_t, P_WpMinus, P_dAnti, 838)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 459)
      call createCurrent(P_uAnti, P_s, P_GPlus, 948)
      call createCurrent(P_t, P_g, P_cAnti, 1398)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 502)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 1176)
      call createCurrent(P_c, P_WpMinus, P_sAnti, 930)
      call createCurrent(P_WPlus, P_tAnti, P_b, 524)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 1359)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 605)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 1066)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_eMinus, 338)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 84)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 1055)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 519)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 525)
      call createCurrent(P_Z, P_u, P_uAnti, 1094)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 956)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 1016)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_A, 750)
      call createCurrent(P_u, P_sAnti, P_GMinus, 624)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_tauMinus, 271)
      call createCurrent(P_WPlus, P_uAnti, P_d, 755)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 103)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 862)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 1095)
      call createCurrent(P_bAnti, P_t, P_WpMinus, 807)
      call createCurrent(P_H, P_GPlus, P_A, P_WMinus, 403)
      call createCurrent(P_uAnti, P_A, P_u, 1056)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 361)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 301)
      call createCurrent(P_Z, P_H, P_WMinus, P_GPlus, 5)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 254)
      call createCurrent(P_sAnti, P_c, P_GMinus, 61)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 1021)
      call createCurrent(P_WMinus, P_t, P_bAnti, 344)
      call createCurrent(P_muPlus, P_H, P_muMinus, 526)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 690)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 1333)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_eAnti, 1129)
      call createCurrent(P_d, P_sAnti, P_G0, 555)
      call createCurrent(P_nu_muAnti, P_eMinus, P_WpPlus, 773)
      call createCurrent(P_H, P_g, P_g, 1436)
      call createCurrent(P_tauMinus, P_H, P_tauPlus, 1283)
      call createCurrent(P_H, P_WPlus, P_H, P_WMinus, 488)
      call createCurrent(P_nu_e, P_nu_eAnti, 1372)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 943)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 1064)
      call createCurrent(P_b, P_Z, P_bAnti, 289)
      call createCurrent(P_d, P_dAnti, P_G0, 82)
      call createCurrent(P_cAnti, P_WPlus, P_s, 1236)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 554)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 1039)
      call createCurrent(P_d, P_uAnti, P_WPlus, 1088)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 1124)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 720)
      call createCurrent(P_b, P_tAnti, P_WPlus, 1017)
      call createCurrent(P_H, P_ghZ, P_ghZAnti, 320)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_Z, 602)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 432)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 532)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 855)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_tau, 1043)
      call createCurrent(P_H, P_Z, P_Z, 859)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_muMinus, 670)
      call createCurrent(P_G0, P_b, P_bAnti, 287)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_e, 881)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 565)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 506)
      call createCurrent(P_muMinus, P_nu_eAnti, P_WpPlus, 472)
      call createCurrent(P_c, P_g, P_uAnti, 1388)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 69)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 913)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 23)
      call createCurrent(P_G0, P_dAnti, P_s, 702)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 304)
      call createCurrent(P_nu_tau, P_WpMinus, P_ePlus, 19)
      call createCurrent(P_c, P_cAnti, P_H, 474)
      call createCurrent(P_bAnti, P_t, P_WMinus, 1261)
      call createCurrent(P_H, P_H, P_H, P_H, 181)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 439)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_A, 51)
      call createCurrent(P_uAnti, P_WPlus, P_d, 877)
      call createCurrent(P_s, P_g, P_dAnti, 1410)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 282)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 60)
      call createCurrent(P_c, P_WMinus, P_dAnti, 406)
      call createCurrent(P_nu_e, P_tauPlus, P_WpMinus, 1305)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_H, 475)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 1092)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 310)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 955)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 546)
      call createCurrent(P_GPlus, P_d, P_uAnti, 581)
      call createCurrent(P_eMinus, P_ePlus, 1362)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 1014)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 988)
      call createCurrent(P_dAnti, P_d, P_H, 648)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_e, 633)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 256)
      call createCurrent(P_WPlus, P_H, P_GMinus, 674)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 147)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 925)
      call createCurrent(P_Z, P_H, P_Z, 827)
      call createCurrent(P_A, P_tAnti, P_t, 223)
      call createCurrent(P_nu_mu, P_WpMinus, P_tauPlus, 1321)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_tauAnti, 121)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 600)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 466)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 1013)
      call createCurrent(P_dAnti, P_g, P_b, 1417)
      call createCurrent(P_uAnti, P_g, P_t, 1418)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 934)
      call createCurrent(P_Z, P_d, P_dAnti, 110)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 13)
      call createCurrent(P_b, P_A, P_bAnti, 575)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 368)
      call createCurrent(P_GMinus, P_c, P_sAnti, 1220)
      call createCurrent(P_WpMinus, P_c, P_sAnti, 280)
      call createCurrent(P_WPlus, P_H, P_Z, P_GMinus, 1284)
      call createCurrent(P_g, P_c, P_cAnti, 464)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 221)
      call createCurrent(P_GMinus, P_H, P_GPlus, P_H, 1279)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 888)
      call createCurrent(P_cAnti, P_s, P_WPlus, 262)
      call createCurrent(P_dAnti, P_G0, P_s, 208)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 458)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 35)
      call createCurrent(P_sAnti, P_d, P_G0, 866)
      call createCurrent(P_c, P_WpMinus, P_bAnti, 514)
      call createCurrent(P_A, P_WPlus, P_H, P_GMinus, 34)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 761)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 944)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 1122)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 67)
      call createCurrent(P_g, P_sAnti, P_s, 327)
      call createCurrent(P_g, P_sAnti, P_d, 1425)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 53)
      call createCurrent(P_GMinus, P_WPlus, 1338)
      call createCurrent(P_WMinus, P_A, P_GPlus, 1335)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WpPlus, 813)
      call createCurrent(P_A, P_t, P_tAnti, 185)
      call createCurrent(P_sAnti, P_GMinus, P_u, 188)
      call createCurrent(P_b, P_G0, P_bAnti, 253)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 1026)
      call createCurrent(P_GPlus, P_s, P_uAnti, 1278)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 700)
      call createCurrent(P_Z, P_s, P_sAnti, 1076)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 497)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 1306)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 589)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 839)
      call createCurrent(P_sAnti, P_s, P_g, 550)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 778)
      call createCurrent(P_GPlus, P_WMinus, P_A, 1008)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_muMinus, 1044)
      call createCurrent(P_tAnti, P_t, P_g, 846)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 52)
      call createCurrent(P_tAnti, P_c, P_g, 1387)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 683)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_tauMinus, 694)
      call createCurrent(P_H, P_Z, P_GPlus, P_WMinus, 490)
      call createCurrent(P_dAnti, P_s, P_g, 1397)
      call createCurrent(P_s, P_WPlus, P_uAnti, 1291)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 1115)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 224)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 914)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 467)
      call createCurrent(P_H, P_bAnti, P_b, 595)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 795)
      call createCurrent(P_t, P_WpMinus, P_sAnti, 1248)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, 419)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 1308)
      call createCurrent(P_uAnti, P_u, P_Z, 159)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 101)
      call createCurrent(P_tAnti, P_b, P_WpPlus, 37)
      call createCurrent(P_GPlus, P_Z, P_H, P_WMinus, 1319)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 494)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 894)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 66)
      call createCurrent(P_GMinus, P_H, P_H, P_GPlus, 127)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 396)
      call createCurrent(P_WpPlus, P_cAnti, P_d, 806)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 1046)
      call createCurrent(P_u, P_WMinus, P_dAnti, 376)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 680)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 1194)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_H, 1257)
      call createCurrent(P_H, P_s, P_sAnti, 139)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 718)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 557)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 999)
      call createCurrent(P_eMinus, P_ePlus, P_H, 1271)
      call createCurrent(P_A, P_bAnti, P_b, 1324)
      call createCurrent(P_ePlus, P_eMinus, 1367)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 537)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 1247)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_mu, 951)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_mu, 1201)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 138)
      call createCurrent(P_t, P_bAnti, P_GMinus, 445)
      call createCurrent(P_uAnti, P_GPlus, P_s, 165)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 762)
      call createCurrent(P_G0, P_H, P_H, P_G0, 460)
      call createCurrent(P_g, P_t, P_cAnti, 1379)
      call createCurrent(P_GMinus, P_H, P_GPlus, 1317)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 190)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 161)
      call createCurrent(P_H, P_WMinus, P_A, P_GPlus, 265)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 111)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 1137)
      call createCurrent(P_g, P_c, P_tAnti, 1444)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 206)
      call createCurrent(P_nu_muAnti, P_nu_mu, 1350)
      call createCurrent(P_WpMinus, P_t, P_dAnti, 794)
      call createCurrent(P_G0, P_s, P_sAnti, 1159)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 623)
      call createCurrent(P_Z, P_H, P_G0, 1037)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 1107)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 1344)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 202)
      call createCurrent(P_WpMinus, P_sAnti, P_c, 766)
      call createCurrent(P_H, P_WPlus, P_A, P_GMinus, 152)
      call createCurrent(P_bAnti, P_d, P_g, 1377)
      call createCurrent(P_tAnti, P_t, P_G0, 1118)
      call createCurrent(P_bAnti, P_GMinus, P_t, 730)
      call createCurrent(P_c, P_uAnti, P_g, 1428)
      call createCurrent(P_s, P_G0, P_sAnti, 273)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 150)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 98)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 418)
      call createCurrent(P_tAnti, P_t, P_H, 826)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 1072)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 922)
      call createCurrent(P_d, P_A, P_dAnti, 342)
      call createCurrent(P_t, P_g, P_uAnti, 1435)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 1167)
      call createCurrent(P_g, P_dAnti, P_b, 1442)
      call createCurrent(P_g, P_bAnti, P_d, 1390)
      call createCurrent(P_H, P_H, P_G0, P_G0, 456)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 723)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 962)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_Z, 1273)
      call createCurrent(P_A, P_WPlus, P_GMinus, 170)
      call createCurrent(P_G0, P_G0, P_H, P_H, 1121)
      call createCurrent(P_tAnti, P_A, P_t, 679)
      call createCurrent(P_d, P_sAnti, P_g, 1412)
      call createCurrent(P_c, P_WMinus, P_sAnti, 448)
      call createCurrent(P_u, P_Z, P_uAnti, 569)
      call createCurrent(P_s, P_sAnti, P_A, 559)
      call createCurrent(P_t, P_tAnti, P_g, 923)
      call createCurrent(P_uAnti, P_s, P_WPlus, 46)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 642)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 891)
      call createCurrent(P_Z, P_bAnti, P_b, 1282)
      call createCurrent(P_WPlus, P_H, P_H, P_WMinus, 843)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 49)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 143)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_A, 1199)
      call createCurrent(P_Z, P_dAnti, P_d, 31)
      call createCurrent(P_b, P_cAnti, P_WpPlus, 390)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 749)
      call createCurrent(P_bAnti, P_b, P_Z, 447)
      call createCurrent(P_A, P_c, P_cAnti, 230)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 872)
      call createCurrent(P_A, P_uAnti, P_u, 785)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 106)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 360)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_eMinus, 1190)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 244)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_eAnti, 1169)
      call createCurrent(P_GPlus, P_A, P_H, P_WMinus, 523)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 149)
      call createCurrent(P_s, P_g, P_sAnti, 434)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 99)
      call createCurrent(P_u, P_sAnti, P_WMinus, 779)
      call createCurrent(P_b, P_g, P_dAnti, 1380)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 511)
      call createCurrent(P_WpMinus, P_bAnti, P_t, 194)
      call createCurrent(P_d, P_uAnti, P_WpPlus, 414)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 708)
      call createCurrent(P_tAnti, P_WPlus, P_b, 1135)
      call createCurrent(P_muMinus, P_muPlus, P_H, 982)
      call createCurrent(P_H, P_s, P_dAnti, 285)
      call createCurrent(P_dAnti, P_d, 1369)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 880)
      call createCurrent(P_s, P_sAnti, P_Z, 1276)
      call createCurrent(P_g, P_H, P_g, 1406)
      call createCurrent(P_H, P_GPlus, P_GMinus, P_H, 226)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 134)
      call createCurrent(P_g, P_d, P_dAnti, 743)
      call createCurrent(P_cAnti, P_g, P_c, 573)
      call createCurrent(P_A, P_cAnti, P_c, 584)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 16)
      call createCurrent(P_g, P_tAnti, P_t, 796)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 765)
      call createCurrent(P_H, P_GMinus, P_Z, P_WPlus, 1262)
      call createCurrent(P_d, P_uAnti, P_GPlus, 798)
      call createCurrent(P_H, P_GPlus, P_WMinus, 1108)
      call createCurrent(P_H, P_tauMinus, P_tauPlus, 267)
      call createCurrent(P_t, P_g, P_tAnti, 1144)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 412)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 668)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 28)
      call createCurrent(P_g, P_uAnti, P_c, 1431)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 315)
      call createCurrent(P_WpMinus, P_nu_tau, P_muPlus, 183)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_Z, 64)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 10)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 42)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 590)
      call createCurrent(P_nu_mu, P_WpMinus, P_ePlus, 1331)
      call createCurrent(P_G0, P_u, P_uAnti, 1141)
      call createCurrent(P_muPlus, P_muMinus, 1357)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 1147)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 1003)
      call createCurrent(P_uAnti, P_G0, P_u, 1325)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 530)
      call createCurrent(P_dAnti, P_d, P_Z, 109)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 568)
      call createCurrent(P_nu_mu, P_tauPlus, P_WpMinus, 157)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 531)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_eAnti, 885)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 1)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 995)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_tauAnti, 618)
      call createCurrent(P_Z, P_b, P_bAnti, 635)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 87)
      call createCurrent(P_t, P_tAnti, P_H, 192)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 369)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 1313)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_eMinus, 141)
      call createCurrent(P_GPlus, P_A, P_GMinus, 1180)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 1025)
      call createCurrent(P_H, P_WMinus, P_H, P_WPlus, 462)
      call createCurrent(P_g, P_u, P_uAnti, 1100)
      call createCurrent(P_eMinus, P_A, P_ePlus, 1146)
      call createCurrent(P_tAnti, P_WpPlus, P_s, 303)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 939)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_tauAnti, 738)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 748)
      call createCurrent(P_GMinus, P_GPlus, P_H, 688)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 770)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 653)
      call createCurrent(P_sAnti, P_s, P_A, 468)
      call createCurrent(P_tAnti, P_d, P_WpPlus, 24)
      call createCurrent(P_H, P_Z, P_H, P_Z, 240)
      call createCurrent(P_WpPlus, P_tAnti, P_b, 975)
      call createCurrent(P_g, P_d, P_bAnti, 1440)
      call createCurrent(P_WpPlus, P_uAnti, P_s, 166)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 480)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 211)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 831)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 969)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 848)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_H, 1172)
      call createCurrent(P_s, P_dAnti, P_H, 234)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 193)
      call createCurrent(P_b, P_uAnti, P_WpPlus, 1175)
      call createCurrent(P_cAnti, P_c, P_g, 275)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 18)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 1084)
      call createCurrent(P_GMinus, P_sAnti, P_u, 125)
      call createCurrent(P_u, P_GMinus, P_sAnti, 541)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_Z, 108)
      call createCurrent(P_A, P_sAnti, P_s, 671)
      call createCurrent(P_nu_mu, P_muPlus, P_WpMinus, 916)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 818)
      call createCurrent(P_d, P_WpPlus, P_uAnti, 842)
      call createCurrent(P_sAnti, P_u, P_WpMinus, 172)
      call createCurrent(P_d, P_dAnti, P_Z, 1024)
      call createCurrent(P_nu_e, P_WpMinus, P_tauPlus, 1085)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_tau, 596)
      call createCurrent(P_dAnti, P_H, P_d, 79)
      call createCurrent(P_u, P_H, P_uAnti, 1104)
      call createCurrent(P_tAnti, P_H, P_t, 195)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 763)
      call createCurrent(P_cAnti, P_s, P_GPlus, 14)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 80)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_e, 1126)
      call createCurrent(P_GMinus, P_A, P_H, P_WPlus, 492)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 465)
      call createCurrent(P_GMinus, P_u, P_dAnti, 295)
      call createCurrent(P_b, P_g, P_sAnti, 1414)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 1111)
      call createCurrent(P_WpMinus, P_WpPlus, 1353)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 306)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 1089)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 736)
      call createCurrent(P_sAnti, P_G0, P_s, 1086)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 851)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 430)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 124)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 279)
      call createCurrent(P_b, P_WpPlus, P_tAnti, 860)
      call createCurrent(P_GMinus, P_c, P_dAnti, 184)
      call createCurrent(P_b, P_bAnti, P_A, 104)
      call createCurrent(P_c, P_bAnti, P_WpMinus, 1269)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 1161)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 1197)
      call createCurrent(P_g, P_g, P_g, P_g, 591)
      call createCurrent(P_dAnti, P_WpMinus, P_c, 30)
      call createCurrent(P_tAnti, P_b, P_WPlus, 1166)
      call createCurrent(P_WpMinus, P_u, P_dAnti, 26)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 997)
      call createCurrent(P_H, P_Z, P_WPlus, P_GMinus, 556)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 1290)
      call createCurrent(P_H, P_H, 1342)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 1272)
      call createCurrent(P_d, P_g, P_sAnti, 1423)
      call createCurrent(P_t, P_WMinus, P_bAnti, 716)
      call createCurrent(P_WPlus, P_cAnti, P_d, 837)
      call createCurrent(P_WpMinus, P_t, P_bAnti, 677)
      call createCurrent(P_H, P_d, P_dAnti, 1216)
      call createCurrent(P_Z, P_GMinus, P_H, P_WPlus, 1178)
      call createCurrent(P_WpMinus, P_u, P_bAnti, 1106)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 973)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_tauMinus, 383)
      call createCurrent(P_WMinus, P_c, P_dAnti, 367)
      call createCurrent(P_dAnti, P_c, P_WpMinus, 578)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_H, 1206)
      call createCurrent(P_H, P_GMinus, P_H, P_GPlus, 792)
      call createCurrent(P_bAnti, P_c, P_WpMinus, 317)
      call createCurrent(P_A, P_GPlus, P_GMinus, 65)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 1221)
      call createCurrent(P_bAnti, P_A, P_b, 528)
      call createCurrent(P_G0, P_t, P_tAnti, 1311)
      call createCurrent(P_cAnti, P_c, P_G0, 517)
      call createCurrent(P_g, P_dAnti, P_s, 1415)
      call createCurrent(P_WPlus, P_d, P_cAnti, 1091)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_A, 1312)
      call createCurrent(P_bAnti, P_g, P_b, 760)
      call createCurrent(P_cAnti, P_d, P_GPlus, 861)
      call createCurrent(P_GMinus, P_A, P_GPlus, 326)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 386)
      call createCurrent(P_muMinus, P_H, P_muPlus, 978)
      call createCurrent(P_nu_e, P_WpMinus, P_ePlus, 1045)
      call createCurrent(P_WPlus, P_GMinus, P_A, 236)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 672)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 217)
      call createCurrent(P_g, P_uAnti, P_u, 119)
      call createCurrent(P_dAnti, P_s, P_H, 876)
      call createCurrent(P_Z, P_H, P_Z, P_H, 659)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 604)
      call createCurrent(P_WpMinus, P_bAnti, P_u, 1171)
      call createCurrent(P_c, P_tAnti, P_g, 1409)
      call createCurrent(P_H, P_ghWmAnti, P_ghWm, 455)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 1332)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_mu, 515)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_H, 797)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_H, 21)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 868)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 1051)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 856)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 470)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WpPlus, 857)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 479)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_eMinus, 299)
      call createCurrent(P_dAnti, P_GMinus, P_c, 377)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 1243)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 890)
      call createCurrent(P_tAnti, P_u, P_g, 1441)
      call createCurrent(P_GPlus, P_uAnti, P_d, 128)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_Z, 186)
      call createCurrent(P_Z, P_cAnti, P_c, 808)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 527)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 239)
      call createCurrent(P_H, P_G0, P_G0, P_H, 1233)
      call createCurrent(P_nu_mu, P_WpMinus, P_muPlus, 1189)
      call createCurrent(P_d, P_bAnti, P_g, 1416)
      call createCurrent(P_cAnti, P_H, P_c, 1334)
      call createCurrent(P_Z, P_H, P_H, P_Z, 954)
      call createCurrent(P_G0, P_G0, P_H, 1063)
      call createCurrent(P_s, P_cAnti, P_GPlus, 63)
      call createCurrent(P_cAnti, P_c, P_A, 348)
      call createCurrent(P_WpMinus, P_nu_mu, P_ePlus, 1142)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_muMinus, 991)
      call createCurrent(P_A, P_WMinus, P_GPlus, 72)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 292)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_tauMinus, 426)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 1322)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_H, 899)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, 438)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 987)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 423)
      call createCurrent(P_b, P_dAnti, P_g, 1384)
      call createCurrent(P_tAnti, P_g, P_u, 1433)
      call createCurrent(P_t, P_dAnti, P_WpMinus, 1267)
      call createCurrent(P_cAnti, P_GPlus, P_s, 802)
      call createCurrent(P_uAnti, P_u, P_A, 669)
      call createCurrent(P_tAnti, P_G0, P_t, 753)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 196)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 1148)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 812)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 775)
      call createCurrent(P_tAnti, P_Z, P_t, 704)
      call createCurrent(P_WMinus, P_u, P_dAnti, 321)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 416)
      call createCurrent(P_g, P_cAnti, P_t, 1392)
      call createCurrent(P_d, P_dAnti, P_H, 1240)
      call createCurrent(P_cAnti, P_WpPlus, P_s, 129)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 349)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 1145)
      call createCurrent(P_cAnti, P_WpPlus, P_b, 713)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 235)
      call createCurrent(P_d, P_WPlus, P_cAnti, 76)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 1307)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 1114)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 156)
      call createCurrent(P_A, P_GMinus, P_H, P_WPlus, 788)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_tau, 357)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 892)
      call createCurrent(P_s, P_H, P_dAnti, 4)
      call createCurrent(P_sAnti, P_Z, P_s, 1028)
      call createCurrent(P_WpPlus, P_uAnti, P_b, 115)
      call createCurrent(P_G0, P_H, P_G0, P_H, 979)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 1179)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, 1130)
      call createCurrent(P_WMinus, P_WPlus, P_H, 1080)
      call createCurrent(P_b, P_tAnti, P_GPlus, 1041)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 324)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 113)
      call createCurrent(P_dAnti, P_A, P_d, 436)
      call createCurrent(P_GPlus, P_WMinus, 1348)
      call createCurrent(P_H, P_GMinus, P_A, P_WPlus, 493)
      call createCurrent(P_Z, P_tAnti, P_t, 444)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_muAnti, 461)
      call createCurrent(P_b, P_tAnti, P_WpPlus, 970)
      call createCurrent(P_bAnti, P_WpMinus, P_t, 630)
      call createCurrent(P_ePlus, P_nu_tau, P_WpMinus, 309)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 933)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 284)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 971)
      call createCurrent(P_s, P_sAnti, 1366)
      call createCurrent(P_cAnti, P_g, P_t, 1432)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_H, 619)
      call createCurrent(P_WPlus, P_d, P_uAnti, 1204)
      call createCurrent(P_WpPlus, P_b, P_tAnti, 1296)
      call createCurrent(P_g, P_tAnti, P_c, 1402)
      call createCurrent(P_u, P_dAnti, P_GMinus, 9)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 356)
      call createCurrent(P_s, P_cAnti, P_WpPlus, 854)
      call createCurrent(P_dAnti, P_s, P_G0, 652)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 263)
      call createCurrent(P_uAnti, P_t, P_g, 1394)
      call createCurrent(P_sAnti, P_c, P_WMinus, 251)
      call createCurrent(P_bAnti, P_t, P_GMinus, 582)
      call createCurrent(P_H, P_WMinus, P_Z, P_GPlus, 429)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 661)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_A, 639)
      call createCurrent(P_WMinus, P_bAnti, P_t, 322)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 647)
      call createCurrent(P_dAnti, P_WMinus, P_c, 727)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 286)
      call createCurrent(P_WMinus, P_WPlus, P_A, 870)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_mu, 902)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 212)
      call createCurrent(P_sAnti, P_GMinus, P_c, 787)
      call createCurrent(P_H, P_u, P_uAnti, 1268)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 354)
      call createCurrent(P_GPlus, P_cAnti, P_s, 151)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 790)
      call createCurrent(P_GPlus, P_H, P_GMinus, 300)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 1224)
      call createCurrent(P_WpPlus, P_cAnti, P_s, 140)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 154)
      call createCurrent(P_Z, P_H, P_GMinus, P_WPlus, 443)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 25)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 1011)
      call createCurrent(P_GPlus, P_GMinus, P_A, 36)
      call createCurrent(P_g, P_bAnti, P_b, 626)
      call createCurrent(P_GPlus, P_d, P_cAnti, 1329)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 1082)
      call createCurrent(P_H, P_WPlus, P_WMinus, P_H, 1004)
      call createCurrent(P_sAnti, P_u, P_WMinus, 805)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 529)
      call createCurrent(P_u, P_GMinus, P_dAnti, 1297)
      call createCurrent(P_tAnti, P_WpPlus, P_d, 961)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 179)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 1214)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 1294)
      call createCurrent(P_WMinus, P_sAnti, P_c, 588)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 1074)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 452)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_H, 220)
      call createCurrent(P_bAnti, P_b, P_A, 1001)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 200)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 473)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 811)
      call createCurrent(P_WpPlus, P_d, P_tAnti, 249)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 486)
      call createCurrent(P_GPlus, P_A, P_WMinus, 629)
      call createCurrent(P_eMinus, P_H, P_ePlus, 1068)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 572)
      call createCurrent(P_b, P_GPlus, P_tAnti, 522)
      call createCurrent(P_u, P_sAnti, P_WpMinus, 381)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 1270)
      call createCurrent(P_muPlus, P_muMinus, P_A, 744)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_H, 998)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 548)
      call createCurrent(P_GMinus, P_GPlus, P_H, P_H, 844)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 657)
      call createCurrent(P_cAnti, P_t, P_g, 1437)
      call createCurrent(P_b, P_WPlus, P_tAnti, 580)
      call createCurrent(P_sAnti, P_g, P_b, 1395)
      call createCurrent(P_u, P_g, P_tAnti, 1378)
      call createCurrent(P_b, P_bAnti, 1355)
      call createCurrent(P_c, P_dAnti, P_WMinus, 400)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 227)
      call createCurrent(P_Z, P_G0, 1364)
      call createCurrent(P_WMinus, P_GPlus, 1346)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 437)
      call createCurrent(P_tauPlus, P_nu_mu, P_WpMinus, 740)
      call createCurrent(P_uAnti, P_g, P_u, 1229)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 62)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 187)
      call createCurrent(P_ePlus, P_A, P_eMinus, 731)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 935)
      call createCurrent(P_g, P_t, P_uAnti, 1382)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 758)
      call createCurrent(P_b, P_H, P_bAnti, 1232)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_muMinus, 513)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 658)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 454)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 972)
      call createCurrent(P_nu_tau, P_ePlus, P_WpMinus, 40)
      call createCurrent(P_H, P_ghWp, P_ghWpAnti, 706)
      call createCurrent(P_dAnti, P_d, P_G0, 1286)
      call createCurrent(P_sAnti, P_c, P_WpMinus, 655)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 0)
      call createCurrent(P_c, P_G0, P_cAnti, 341)
      call createCurrent(P_H, P_GMinus, P_GPlus, P_H, 145)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 420)
      call createCurrent(P_b, P_sAnti, P_g, 1443)
      call createCurrent(P_Z, P_H, P_WPlus, P_GMinus, 516)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 1225)
      call createCurrent(P_G0, P_d, P_sAnti, 1155)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 380)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WpPlus, 821)
      call createCurrent(P_H, P_G0, P_G0, 924)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_Z, 1310)
      call createCurrent(P_uAnti, P_d, P_WPlus, 616)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 189)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 1087)
      call createCurrent(P_GPlus, P_H, P_WMinus, 1277)
      call createCurrent(P_A, P_GMinus, P_GPlus, 1192)
      call createCurrent(P_A, P_dAnti, P_d, 114)
      call createCurrent(P_Z, P_H, P_GPlus, P_WMinus, 1230)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 1133)
      call createCurrent(P_c, P_sAnti, P_GMinus, 963)
      call createCurrent(P_H, P_WMinus, P_WPlus, P_H, 784)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 1295)
      call createCurrent(P_g, P_d, P_sAnti, 1401)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 1073)
      call createCurrent(P_tAnti, P_t, 1358)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 334)
      call createCurrent(P_muMinus, P_nu_tauAnti, P_WpPlus, 485)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 191)
      call createCurrent(P_t, P_uAnti, P_g, 1404)
      call createCurrent(P_u, P_uAnti, P_G0, 118)
      call createCurrent(P_g, P_u, P_cAnti, 1400)
      call createCurrent(P_bAnti, P_WpMinus, P_c, 451)
      call createCurrent(P_H, P_tAnti, P_t, 442)
      call createCurrent(P_t, P_G0, P_tAnti, 1213)
      call createCurrent(P_H, P_H, P_Z, P_Z, 453)
      call createCurrent(P_WPlus, P_A, P_H, P_GMinus, 946)
      call createCurrent(P_GMinus, P_Z, P_H, P_WPlus, 487)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 1314)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 1110)
      call createCurrent(P_WpPlus, P_tAnti, P_d, 1012)
      call createCurrent(P_WPlus, P_H, P_A, P_GMinus, 986)
      call createCurrent(P_cAnti, P_b, P_WpPlus, 879)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 592)
      call createCurrent(P_t, P_H, P_tAnti, 38)
      call createCurrent(P_GPlus, P_GMinus, P_H, P_H, 375)
      call createCurrent(P_tauMinus, P_nu_eAnti, P_WpPlus, 932)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 518)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 603)
      call createCurrent(P_t, P_GMinus, P_bAnti, 783)
      call createCurrent(P_bAnti, P_WpMinus, P_u, 737)
      call createCurrent(P_H, P_G0, P_H, P_G0, 1191)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 752)
      call createCurrent(P_sAnti, P_s, 1354)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 1254)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 836)
      call createCurrent(P_s, P_G0, P_dAnti, 803)
      call createCurrent(P_H, P_uAnti, P_u, 840)
      call createCurrent(P_u, P_A, P_uAnti, 48)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 882)
      call createCurrent(P_uAnti, P_WpPlus, P_b, 561)
      call createCurrent(P_A, P_u, P_uAnti, 609)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 1315)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 599)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 347)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 1160)
      call createCurrent(P_WpPlus, P_WpMinus, 1337)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, 816)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 398)
      call createCurrent(P_s, P_uAnti, P_WpPlus, 1099)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_Z, 257)
      call createCurrent(P_dAnti, P_GMinus, P_u, 352)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 483)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, 631)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 415)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 545)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 974)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 1318)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 1150)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 291)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 160)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 177)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_Z, 767)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_H, 8)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 268)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 355)
      call createCurrent(P_WPlus, P_s, P_uAnti, 791)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 1285)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_H, 407)
      call createCurrent(P_H, P_GPlus, P_Z, P_WMinus, 215)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 1320)
      call createCurrent(P_H, P_ghWm, P_ghWmAnti, 1193)
      call createCurrent(P_g, P_b, P_sAnti, 1408)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 734)
      call createCurrent(P_WpMinus, P_u, P_sAnti, 463)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 504)
      call createCurrent(P_WpMinus, P_t, P_sAnti, 27)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, 873)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 992)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 1207)
      call createCurrent(P_WpMinus, P_nu_tau, P_ePlus, 895)
      call createCurrent(P_muMinus, P_A, P_muPlus, 845)
      call createCurrent(P_u, P_uAnti, P_H, 364)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 489)
      call createCurrent(P_G0, P_s, P_dAnti, 1195)
      call createCurrent(P_u, P_WMinus, P_sAnti, 296)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 673)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 1293)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_muAnti, 359)
      call createCurrent(P_b, P_bAnti, P_H, 330)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 105)
      call createCurrent(P_WMinus, P_WPlus, P_H, P_H, 1097)
      call createCurrent(P_d, P_dAnti, P_g, 613)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WpPlus, 621)
      call createCurrent(P_WMinus, P_GPlus, P_A, 1065)
      call createCurrent(P_g, P_s, P_bAnti, 1381)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 171)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 1288)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 612)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 1185)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 597)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, 213)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 89)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, 646)
      call createCurrent(P_u, P_WpMinus, P_sAnti, 563)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_H, 741)
      call createCurrent(P_Z, P_WPlus, P_H, P_GMinus, 904)
      call createCurrent(P_g, P_c, P_uAnti, 1430)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_H, 769)
      call createCurrent(P_c, P_g, P_cAnti, 336)
      call createCurrent(P_c, P_cAnti, P_Z, 776)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 329)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 1113)
      call createCurrent(P_WPlus, P_WMinus, P_H, 261)
      call createCurrent(P_dAnti, P_Z, P_d, 499)
      call createCurrent(P_u, P_bAnti, P_WpMinus, 505)
      call createCurrent(P_ePlus, P_nu_mu, P_WpMinus, 710)
      call createCurrent(P_A, P_GMinus, P_WPlus, 323)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 346)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 314)
      call createCurrent(P_sAnti, P_WMinus, P_c, 97)
      call createCurrent(P_uAnti, P_u, P_G0, 883)
      call createCurrent(P_GPlus, P_tAnti, P_b, 1093)
      call createCurrent(P_H, P_H, P_GMinus, P_GPlus, 660)
      call createCurrent(P_ghZAnti, P_ghZ, P_H, 1227)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 401)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 131)
      call createCurrent(P_d, P_tAnti, P_WpPlus, 1242)
      call createCurrent(P_uAnti, P_H, P_u, 71)
      call createCurrent(P_s, P_bAnti, P_g, 1385)
      call createCurrent(P_g, P_bAnti, P_s, 1427)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_muMinus, 225)
      call createCurrent(P_nu_eAnti, P_tauMinus, P_WpPlus, 1208)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 585)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 55)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 130)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 1253)
      call createCurrent(P_WpMinus, P_nu_mu, P_muPlus, 435)
      call createCurrent(P_tauPlus, P_nu_e, P_WpMinus, 512)
      call createCurrent(P_GMinus, P_GPlus, P_A, 408)
      call createCurrent(P_dAnti, P_u, P_WpMinus, 353)
      call createCurrent(P_b, P_bAnti, P_Z, 684)
      call createCurrent(P_nu_tau, P_WpMinus, P_muPlus, 1005)
      call createCurrent(P_Z, P_Z, 1349)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 1280)
      call createCurrent(P_A, P_eMinus, P_ePlus, 1245)
      call createCurrent(P_H, P_GPlus, P_GMinus, 952)
      call createCurrent(P_WMinus, P_A, P_WPlus, 20)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 95)
      call createCurrent(P_t, P_bAnti, P_WpMinus, 441)
      call createCurrent(P_dAnti, P_b, P_g, 1375)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 833)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 719)
      call createCurrent(P_nu_tauAnti, P_muMinus, P_WpPlus, 632)
      call createCurrent(P_Z, P_sAnti, P_s, 853)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 54)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 481)
      call createCurrent(P_tAnti, P_s, P_WpPlus, 1156)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 1149)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 11)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 1323)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 288)
      call createCurrent(P_eMinus, P_nu_muAnti, P_WpPlus, 73)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, 697)
      call createCurrent(P_GMinus, P_H, P_WPlus, 1139)
      call createCurrent(P_s, P_uAnti, P_WPlus, 425)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 920)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 764)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 298)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 823)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_tau, 374)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 564)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WpPlus, 1265)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_tauMinus, 867)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 583)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_eAnti, 940)
      call createCurrent(P_WMinus, P_H, P_A, P_GPlus, 707)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 393)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 886)
      call createCurrent(P_cAnti, P_G0, P_c, 1301)
      call createCurrent(P_WpMinus, P_dAnti, P_u, 789)
      call createCurrent(P_H, P_A, P_GPlus, P_WMinus, 824)
      call createCurrent(P_c, P_GMinus, P_sAnti, 1057)
      call createCurrent(P_WPlus, P_s, P_cAnti, 163)
      call createCurrent(P_WMinus, P_WPlus, 1373)
      call createCurrent(P_H, P_eMinus, P_ePlus, 33)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 1042)
      call createCurrent(P_bAnti, P_H, P_b, 1215)
      call createCurrent(P_WpPlus, P_d, P_uAnti, 491)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 915)
      call createCurrent(P_Z, P_Z, P_H, P_H, 617)
      call createCurrent(P_g, P_s, P_sAnti, 409)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, 576)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 941)
      call createCurrent(P_H, P_A, P_WPlus, P_GMinus, 964)
      call createCurrent(P_WMinus, P_A, P_H, P_GPlus, 363)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 1231)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 815)
      call createCurrent(P_c, P_A, P_cAnti, 476)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 116)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 248)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 703)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 547)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_mu, 450)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 478)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 399)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 1274)
      call createCurrent(P_cAnti, P_WPlus, P_d, 521)
      call createCurrent(P_bAnti, P_b, 1352)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 751)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 1198)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 989)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_muAnti, 417)
      call createCurrent(P_muPlus, P_nu_e, P_WpMinus, 59)
      call createCurrent(P_t, P_tAnti, P_Z, 786)
      call createCurrent(P_uAnti, P_g, P_c, 1399)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 232)
      call createCurrent(P_nu_tau, P_muPlus, P_WpMinus, 68)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 146)
      call createCurrent(P_s, P_g, P_bAnti, 1422)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 332)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 203)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 828)
      call createCurrent(P_WPlus, P_WMinus, P_A, 1136)
      call createCurrent(P_A, P_muMinus, P_muPlus, 1196)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 1302)
      call createCurrent(P_bAnti, P_u, P_WpMinus, 832)
      call createCurrent(P_H, P_ePlus, P_eMinus, 543)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_H, 1168)
      call createCurrent(P_g, P_b, P_dAnti, 1424)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 960)
      call createCurrent(P_u, P_WpMinus, P_bAnti, 135)
      call createCurrent(P_WpPlus, P_s, P_uAnti, 721)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_tauMinus, 290)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 1125)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 1128)
      call createCurrent(P_dAnti, P_u, P_WMinus, 1060)
      call createCurrent(P_uAnti, P_d, P_GPlus, 219)
      call createCurrent(P_s, P_sAnti, P_G0, 756)
      call createCurrent(P_uAnti, P_c, P_g, 1421)
      call createCurrent(P_dAnti, P_H, P_s, 102)
      call createCurrent(P_d, P_g, P_bAnti, 1446)
      call createCurrent(P_GMinus, P_H, P_Z, P_WPlus, 1049)
      call createCurrent(P_bAnti, P_s, P_g, 1420)
      call createCurrent(P_H, P_WPlus, P_Z, P_GMinus, 1210)
      call createCurrent(P_u, P_WpMinus, P_dAnti, 1163)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 198)
      call createCurrent(P_ePlus, P_H, P_eMinus, 389)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 912)
      call createCurrent(P_sAnti, P_H, P_d, 93)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 539)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 427)
      call createCurrent(P_Z, P_t, P_tAnti, 692)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 266)
      call createCurrent(P_tAnti, P_WpPlus, P_b, 1241)
      call createCurrent(P_Z, P_c, P_cAnti, 201)
      call createCurrent(P_tAnti, P_b, P_GPlus, 967)
      call createCurrent(P_H, P_GPlus, P_H, P_GMinus, 889)
      call createCurrent(P_sAnti, P_G0, P_d, 687)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 1165)
      call createCurrent(P_b, P_g, P_bAnti, 722)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 431)
      call createCurrent(P_WPlus, P_H, P_WMinus, P_H, 553)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 574)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 241)
      call createCurrent(P_H, P_GMinus, P_GPlus, 1019)
      call createCurrent(P_sAnti, P_WpMinus, P_t, 509)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 1235)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 780)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 117)
      call createCurrent(P_WpPlus, P_b, P_uAnti, 587)
      call createCurrent(P_sAnti, P_d, P_H, 643)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_tauAnti, 900)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 911)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 1027)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_muAnti, 1002)
      call createCurrent(P_WMinus, P_H, P_WPlus, P_H, 1266)
      call createCurrent(P_H, P_dAnti, P_d, 498)
      call createCurrent(P_sAnti, P_g, P_d, 1405)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 676)
      call createCurrent(P_WpPlus, P_d, P_cAnti, 1205)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 91)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, 665)
      call createCurrent(P_H, P_c, P_cAnti, 339)
      call createCurrent(P_g, P_sAnti, P_b, 1439)
      call createCurrent(P_Z, P_G0, P_H, 242)
      call createCurrent(P_g, P_dAnti, P_d, 544)
      call createCurrent(P_bAnti, P_g, P_d, 1393)
      call createCurrent(P_GMinus, P_t, P_bAnti, 685)
      call createCurrent(P_bAnti, P_b, P_H, 1154)
      call createCurrent(P_d, P_Z, P_dAnti, 122)
      call createCurrent(P_tauPlus, P_tauMinus, P_H, 174)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 871)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 1303)
      call createCurrent(P_t, P_A, P_tAnti, 622)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_A, 1069)
      call createCurrent(P_G0, P_Z, P_H, 1246)
      call createCurrent(P_cAnti, P_c, P_Z, 829)
      call createCurrent(P_uAnti, P_u, P_H, 1152)
      call createCurrent(P_GMinus, P_sAnti, P_c, 638)
      call createCurrent(P_ghZ, P_H, P_ghZAnti, 754)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 709)
      call createCurrent(P_b, P_WpPlus, P_uAnti, 822)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 606)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 1212)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 980)
      call createCurrent(P_WpMinus, P_nu_e, P_tauPlus, 566)
      call createCurrent(P_H, P_H, P_WPlus, P_WMinus, 654)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 958)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 1239)
      call createCurrent(P_cAnti, P_u, P_g, 1386)
      call createCurrent(P_dAnti, P_G0, P_d, 852)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 245)
      call createCurrent(P_A, P_A, 1340)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 711)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, 392)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 640)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 820)
      call createCurrent(P_WPlus, P_cAnti, P_s, 199)
      call createCurrent(P_cAnti, P_d, P_WpPlus, 337)
      call createCurrent(P_cAnti, P_c, P_H, 909)
      call createCurrent(P_GPlus, P_GMinus, P_H, 264)
      call createCurrent(P_tAnti, P_g, P_t, 32)
      call createCurrent(P_t, P_WpMinus, P_bAnti, 209)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 1034)
      call createCurrent(P_WpMinus, P_c, P_dAnti, 993)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 1260)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 906)
      call createCurrent(P_u, P_uAnti, P_A, 1328)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_H, 136)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 1058)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 774)
      call createCurrent(P_WMinus, P_sAnti, P_u, 607)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 1226)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 1157)
      call createCurrent(P_WPlus, P_H, P_WMinus, 620)
      call createCurrent(P_g, P_cAnti, P_u, 1426)
      call createCurrent(P_Z, P_WMinus, P_H, P_GPlus, 1029)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 1217)
      call createCurrent(P_t, P_cAnti, P_g, 1411)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_muAnti, 243)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 469)
    end subroutine init_vertices_mdl

    subroutine check_vertices_mdl()
      integer(kind=8) :: config
      integer :: res, address
      logical :: found
      call createParticleConfig(P_GMinus, P_G0, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",819
      if ( res /= 819) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GPlus, P_GMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",628
      if ( res /= 628) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_b, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",594
      if ( res /= 594) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",313
      if ( res /= 313) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",449
      if ( res /= 449) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",835
      if ( res /= 835) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_tAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",350
      if ( res /= 350) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_A, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",365
      if ( res /= 365) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_dAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",593
      if ( res /= 593) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_H, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",218
      if ( res /= 218) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_uAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",231
      if ( res /= 231) then
        stop
      end if
      call createParticleConfig(P_H, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",204
      if ( res /= 204) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_s, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",100
      if ( res /= 100) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",579
      if ( res /= 579) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghWmAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",3
      if ( res /= 3) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1048
      if ( res /= 1048) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_WpPlus, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",793
      if ( res /= 793) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_nu_e, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",44
      if ( res /= 44) then
        stop
      end if
      call createParticleConfig(P_g, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1238
      if ( res /= 1238) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",126
      if ( res /= 126) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",691
      if ( res /= 691) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_g, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1389
      if ( res /= 1389) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_g, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1177
      if ( res /= 1177) then
        stop
      end if
      call createParticleConfig(P_c, P_GMinus, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",601
      if ( res /= 601) then
        stop
      end if
      call createParticleConfig(P_A, P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",269
      if ( res /= 269) then
        stop
      end if
      call createParticleConfig(P_s, P_WpPlus, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",345
      if ( res /= 345) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_H, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",884
      if ( res /= 884) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",865
      if ( res /= 865) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_eMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1022
      if ( res /= 1022) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_WpPlus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",378
      if ( res /= 378) then
        stop
      end if
      call createParticleConfig(P_Z, P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",308
      if ( res /= 308) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_dAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",782
      if ( res /= 782) then
        stop
      end if
      call createParticleConfig(P_u, P_cAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1448
      if ( res /= 1448) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_H, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",197
      if ( res /= 197) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghWmAnti, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",759
      if ( res /= 759) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",942
      if ( res /= 942) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1183
      if ( res /= 1183) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1109
      if ( res /= 1109) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",495
      if ( res /= 495) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_H, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",896
      if ( res /= 896) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_WpMinus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",233
      if ( res /= 233) then
        stop
      end if
      call createParticleConfig(P_A, P_ghWm, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",804
      if ( res /= 804) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1249
      if ( res /= 1249) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_Z, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",735
      if ( res /= 735) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_WPlus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",500
      if ( res /= 500) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",937
      if ( res /= 937) then
        stop
      end if
      call createParticleConfig(P_Z, P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1077
      if ( res /= 1077) then
        stop
      end if
      call createParticleConfig(P_g, P_u, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1445
      if ( res /= 1445) then
        stop
      end if
      call createParticleConfig(P_A, P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1117
      if ( res /= 1117) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",39
      if ( res /= 39) then
        stop
      end if
      call createParticleConfig(P_t, P_Z, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",558
      if ( res /= 558) then
        stop
      end if
      call createParticleConfig(P_G0, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",50
      if ( res /= 50) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_GMinus, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",910
      if ( res /= 910) then
        stop
      end if
      call createParticleConfig(P_s, P_Z, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",351
      if ( res /= 351) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",92
      if ( res /= 92) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_WMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",272
      if ( res /= 272) then
        stop
      end if
      call createParticleConfig(P_H, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",887
      if ( res /= 887) then
        stop
      end if
      call createParticleConfig(P_H, P_H, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",801
      if ( res /= 801) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_dAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",496
      if ( res /= 496) then
        stop
      end if
      call createParticleConfig(P_H, P_sAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",966
      if ( res /= 966) then
        stop
      end if
      call createParticleConfig(P_A, P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1237
      if ( res /= 1237) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GMinus, P_GPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",729
      if ( res /= 729) then
        stop
      end if
      call createParticleConfig(P_H, P_Z, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",318
      if ( res /= 318) then
        stop
      end if
      call createParticleConfig(P_G0, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",333
      if ( res /= 333) then
        stop
      end if
      call createParticleConfig(P_u, P_g, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1419
      if ( res /= 1419) then
        stop
      end if
      call createParticleConfig(P_G0, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1256
      if ( res /= 1256) then
        stop
      end if
      call createParticleConfig(P_s, P_uAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",305
      if ( res /= 305) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",712
      if ( res /= 712) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_nu_muAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",7
      if ( res /= 7) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",307
      if ( res /= 307) then
        stop
      end if
      call createParticleConfig(P_c, P_g, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1413
      if ( res /= 1413) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_s, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",695
      if ( res /= 695) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_WpMinus, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",404
      if ( res /= 404) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_nu_muAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",552
      if ( res /= 552) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_t, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1174
      if ( res /= 1174) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1101
      if ( res /= 1101) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",586
      if ( res /= 586) then
        stop
      end if
      call createParticleConfig(P_A, P_H, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",411
      if ( res /= 411) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",533
      if ( res /= 533) then
        stop
      end if
      call createParticleConfig(P_Z, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",610
      if ( res /= 610) then
        stop
      end if
      call createParticleConfig(P_H, P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",471
      if ( res /= 471) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_H, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",424
      if ( res /= 424) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",74
      if ( res /= 74) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_GPlus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",277
      if ( res /= 277) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_H, P_GMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",926
      if ( res /= 926) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",929
      if ( res /= 929) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_H, P_H, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",387
      if ( res /= 387) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_g, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1112
      if ( res /= 1112) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_muPlus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",901
      if ( res /= 901) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1299
      if ( res /= 1299) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_nu_muAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",123
      if ( res /= 123) then
        stop
      end if
      call createParticleConfig(P_H, P_dAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",917
      if ( res /= 917) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_GPlus, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",112
      if ( res /= 112) then
        stop
      end if
      call createParticleConfig(P_G0, P_sAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",259
      if ( res /= 259) then
        stop
      end if
      call createParticleConfig(P_u, P_tAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1438
      if ( res /= 1438) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",598
      if ( res /= 598) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_nu_e, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",666
      if ( res /= 666) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghWm, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1032
      if ( res /= 1032) then
        stop
      end if
      call createParticleConfig(P_b, P_WpPlus, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",155
      if ( res /= 155) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_WMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",732
      if ( res /= 732) then
        stop
      end if
      call createParticleConfig(P_c, P_sAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",615
      if ( res /= 615) then
        stop
      end if
      call createParticleConfig(P_c, P_WpMinus, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",205
      if ( res /= 205) then
        stop
      end if
      call createParticleConfig(P_A, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1070
      if ( res /= 1070) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_c, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1258
      if ( res /= 1258) then
        stop
      end if
      call createParticleConfig(P_H, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1255
      if ( res /= 1255) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_tauMinus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1211
      if ( res /= 1211) then
        stop
      end if
      call createParticleConfig(P_H, P_H, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",733
      if ( res /= 733) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghZ, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",278
      if ( res /= 278) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_nu_mu, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1052
      if ( res /= 1052) then
        stop
      end if
      call createParticleConfig(P_d, P_WpPlus, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",800
      if ( res /= 800) then
        stop
      end if
      call createParticleConfig(P_H, P_WPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",847
      if ( res /= 847) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",379
      if ( res /= 379) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1374
      if ( res /= 1374) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_bAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1134
      if ( res /= 1134) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_H, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1218
      if ( res /= 1218) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_A, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",252
      if ( res /= 252) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1244
      if ( res /= 1244) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",45
      if ( res /= 45) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_eMinus, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",302
      if ( res /= 302) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_WpPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",57
      if ( res /= 57) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_WPlus, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1252
      if ( res /= 1252) then
        stop
      end if
      call createParticleConfig(P_d, P_H, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",180
      if ( res /= 180) then
        stop
      end if
      call createParticleConfig(P_t, P_sAnti, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",938
      if ( res /= 938) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_WpPlus, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1009
      if ( res /= 1009) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghZAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",362
      if ( res /= 362) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",898
      if ( res /= 898) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",678
      if ( res /= 678) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_WpMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",384
      if ( res /= 384) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_s, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",850
      if ( res /= 850) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_A, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",841
      if ( res /= 841) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_muMinus, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",94
      if ( res /= 94) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_H, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",175
      if ( res /= 175) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1347
      if ( res /= 1347) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_H, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1053
      if ( res /= 1053) then
        stop
      end if
      call createParticleConfig(P_s, P_WpPlus, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1006
      if ( res /= 1006) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1023
      if ( res /= 1023) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",484
      if ( res /= 484) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_g, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1396
      if ( res /= 1396) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",542
      if ( res /= 542) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1292
      if ( res /= 1292) then
        stop
      end if
      call createParticleConfig(P_d, P_cAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1103
      if ( res /= 1103) then
        stop
      end if
      call createParticleConfig(P_G0, P_H, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",649
      if ( res /= 649) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_dAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",255
      if ( res /= 255) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",276
      if ( res /= 276) then
        stop
      end if
      call createParticleConfig(P_A, P_H, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1287
      if ( res /= 1287) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",945
      if ( res /= 945) then
        stop
      end if
      call createParticleConfig(P_s, P_H, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",651
      if ( res /= 651) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1371
      if ( res /= 1371) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",153
      if ( res /= 153) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_cAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",686
      if ( res /= 686) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_eMinus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1035
      if ( res /= 1035) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_b, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1403
      if ( res /= 1403) then
        stop
      end if
      call createParticleConfig(P_c, P_sAnti, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",534
      if ( res /= 534) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_H, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",724
      if ( res /= 724) then
        stop
      end if
      call createParticleConfig(P_G0, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",919
      if ( res /= 919) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",745
      if ( res /= 745) then
        stop
      end if
      call createParticleConfig(P_s, P_dAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1202
      if ( res /= 1202) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_WpMinus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1116
      if ( res /= 1116) then
        stop
      end if
      call createParticleConfig(P_s, P_GPlus, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",382
      if ( res /= 382) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_d, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",994
      if ( res /= 994) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1090
      if ( res /= 1090) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",928
      if ( res /= 928) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",260
      if ( res /= 260) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",297
      if ( res /= 297) then
        stop
      end if
      call createParticleConfig(P_g, P_s, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1429
      if ( res /= 1429) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1356
      if ( res /= 1356) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_H, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",440
      if ( res /= 440) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_c, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",927
      if ( res /= 927) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",641
      if ( res /= 641) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_s, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",501
      if ( res /= 501) then
        stop
      end if
      call createParticleConfig(P_A, P_H, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",650
      if ( res /= 650) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_GPlus, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1164
      if ( res /= 1164) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_nu_tauAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",43
      if ( res /= 43) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1033
      if ( res /= 1033) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_Z, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",394
      if ( res /= 394) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghA, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1030
      if ( res /= 1030) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_nu_e, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1219
      if ( res /= 1219) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_H, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",132
      if ( res /= 132) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1360
      if ( res /= 1360) then
        stop
      end if
      call createParticleConfig(P_H, P_A, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1047
      if ( res /= 1047) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_ePlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",81
      if ( res /= 81) then
        stop
      end if
      call createParticleConfig(P_H, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1228
      if ( res /= 1228) then
        stop
      end if
      call createParticleConfig(P_d, P_GPlus, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1184
      if ( res /= 1184) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_d, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",133
      if ( res /= 133) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_nu_tau, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",858
      if ( res /= 858) then
        stop
      end if
      call createParticleConfig(P_d, P_sAnti, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1081
      if ( res /= 1081) then
        stop
      end if
      call createParticleConfig(P_G0, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1251
      if ( res /= 1251) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_G0, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",947
      if ( res /= 947) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",908
      if ( res /= 908) then
        stop
      end if
      call createParticleConfig(P_H, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",905
      if ( res /= 905) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghZAnti, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",83
      if ( res /= 83) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_nu_muAnti, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",907
      if ( res /= 907) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_Z, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1098
      if ( res /= 1098) then
        stop
      end if
      call createParticleConfig(P_G0, P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",984
      if ( res /= 984) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",388
      if ( res /= 388) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",77
      if ( res /= 77) then
        stop
      end if
      call createParticleConfig(P_s, P_GPlus, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",715
      if ( res /= 715) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_nu_tau, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",12
      if ( res /= 12) then
        stop
      end if
      call createParticleConfig(P_H, P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",395
      if ( res /= 395) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1339
      if ( res /= 1339) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",167
      if ( res /= 167) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_tauAnti, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",85
      if ( res /= 85) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_WpMinus, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",294
      if ( res /= 294) then
        stop
      end if
      call createParticleConfig(P_c, P_dAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",15
      if ( res /= 15) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_GMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1007
      if ( res /= 1007) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",726
      if ( res /= 726) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_WpPlus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1187
      if ( res /= 1187) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_A, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",810
      if ( res /= 810) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",540
      if ( res /= 540) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1188
      if ( res /= 1188) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1200
      if ( res /= 1200) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_GPlus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",777
      if ( res /= 777) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_Z, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",931
      if ( res /= 931) then
        stop
      end if
      call createParticleConfig(P_d, P_G0, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",656
      if ( res /= 656) then
        stop
      end if
      call createParticleConfig(P_s, P_WPlus, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",570
      if ( res /= 570) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_WMinus, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",144
      if ( res /= 144) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_uAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",216
      if ( res /= 216) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_A, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",413
      if ( res /= 413) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1316
      if ( res /= 1316) then
        stop
      end if
      call createParticleConfig(P_d, P_cAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",29
      if ( res /= 29) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_nu_tau, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1140
      if ( res /= 1140) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_nu_mu, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1050
      if ( res /= 1050) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1059
      if ( res /= 1059) then
        stop
      end if
      call createParticleConfig(P_u, P_dAnti, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1209
      if ( res /= 1209) then
        stop
      end if
      call createParticleConfig(P_A, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",405
      if ( res /= 405) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",70
      if ( res /= 70) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_ePlus, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",728
      if ( res /= 728) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_H, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1015
      if ( res /= 1015) then
        stop
      end if
      call createParticleConfig(P_H, P_d, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",370
      if ( res /= 370) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",965
      if ( res /= 965) then
        stop
      end if
      call createParticleConfig(P_A, P_H, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",340
      if ( res /= 340) then
        stop
      end if
      call createParticleConfig(P_d, P_g, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",567
      if ( res /= 567) then
        stop
      end if
      call createParticleConfig(P_g, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1096
      if ( res /= 1096) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1264
      if ( res /= 1264) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1361
      if ( res /= 1361) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_WPlus, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",56
      if ( res /= 56) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_WMinus, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",634
      if ( res /= 634) then
        stop
      end if
      call createParticleConfig(P_s, P_dAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1449
      if ( res /= 1449) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1370
      if ( res /= 1370) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GMinus, P_GPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",373
      if ( res /= 373) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",372
      if ( res /= 372) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",457
      if ( res /= 457) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",771
      if ( res /= 771) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_H, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",258
      if ( res /= 258) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",577
      if ( res /= 577) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_H, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1054
      if ( res /= 1054) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1343
      if ( res /= 1343) then
        stop
      end if
      call createParticleConfig(P_t, P_bAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1119
      if ( res /= 1119) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_H, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",675
      if ( res /= 675) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_WpPlus, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",311
      if ( res /= 311) then
        stop
      end if
      call createParticleConfig(P_g, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",667
      if ( res /= 667) then
        stop
      end if
      call createParticleConfig(P_A, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",699
      if ( res /= 699) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",164
      if ( res /= 164) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_d, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1407
      if ( res /= 1407) then
        stop
      end if
      call createParticleConfig(P_c, P_H, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",662
      if ( res /= 662) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",6
      if ( res /= 6) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_nu_tau, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",477
      if ( res /= 477) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1102
      if ( res /= 1102) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_u, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",950
      if ( res /= 950) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",814
      if ( res /= 814) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",148
      if ( res /= 148) then
        stop
      end if
      call createParticleConfig(P_d, P_H, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",625
      if ( res /= 625) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1300
      if ( res /= 1300) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1275
      if ( res /= 1275) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_sAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",107
      if ( res /= 107) then
        stop
      end if
      call createParticleConfig(P_u, P_G0, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",893
      if ( res /= 893) then
        stop
      end if
      call createParticleConfig(P_H, P_A, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",331
      if ( res /= 331) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_tauMinus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",176
      if ( res /= 176) then
        stop
      end if
      call createParticleConfig(P_G0, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",864
      if ( res /= 864) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghWm, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1151
      if ( res /= 1151) then
        stop
      end if
      call createParticleConfig(P_H, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",391
      if ( res /= 391) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",446
      if ( res /= 446) then
        stop
      end if
      call createParticleConfig(P_G0, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",903
      if ( res /= 903) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_WpMinus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",921
      if ( res /= 921) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",985
      if ( res /= 985) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_G0, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1234
      if ( res /= 1234) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",538
      if ( res /= 538) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1010
      if ( res /= 1010) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_GPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",371
      if ( res /= 371) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_ePlus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1158
      if ( res /= 1158) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",705
      if ( res /= 705) then
        stop
      end if
      call createParticleConfig(P_g, P_tAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1434
      if ( res /= 1434) then
        stop
      end if
      call createParticleConfig(P_d, P_GPlus, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",228
      if ( res /= 228) then
        stop
      end if
      call createParticleConfig(P_H, P_Z, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",41
      if ( res /= 41) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",698
      if ( res /= 698) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",682
      if ( res /= 682) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_H, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",510
      if ( res /= 510) then
        stop
      end if
      call createParticleConfig(P_c, P_dAnti, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1067
      if ( res /= 1067) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",178
      if ( res /= 178) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_GMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",410
      if ( res /= 410) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1038
      if ( res /= 1038) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1330
      if ( res /= 1330) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghZAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",158
      if ( res /= 158) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghWmAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",977
      if ( res /= 977) then
        stop
      end if
      call createParticleConfig(P_Z, P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",319
      if ( res /= 319) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_WMinus, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",96
      if ( res /= 96) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1304
      if ( res /= 1304) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_dAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",560
      if ( res /= 560) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",663
      if ( res /= 663) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_GMinus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",717
      if ( res /= 717) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_WPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",433
      if ( res /= 433) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghWp, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",953
      if ( res /= 953) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_tauPlus, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",809
      if ( res /= 809) then
        stop
      end if
      call createParticleConfig(P_d, P_WpPlus, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",168
      if ( res /= 168) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",834
      if ( res /= 834) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_nu_e, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",693
      if ( res /= 693) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",182
      if ( res /= 182) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",402
      if ( res /= 402) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1368
      if ( res /= 1368) then
        stop
      end if
      call createParticleConfig(P_c, P_Z, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",849
      if ( res /= 849) then
        stop
      end if
      call createParticleConfig(P_H, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",976
      if ( res /= 976) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1203
      if ( res /= 1203) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_u, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",981
      if ( res /= 981) then
        stop
      end if
      call createParticleConfig(P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1341
      if ( res /= 1341) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",137
      if ( res /= 137) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghWp, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1000
      if ( res /= 1000) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WPlus, P_GMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",2
      if ( res /= 2) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",507
      if ( res /= 507) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_H, P_H, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",47
      if ( res /= 47) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_nu_eAnti, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",328
      if ( res /= 328) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",247
      if ( res /= 247) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",746
      if ( res /= 746) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_H, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",385
      if ( res /= 385) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghA, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",608
      if ( res /= 608) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1075
      if ( res /= 1075) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1263
      if ( res /= 1263) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_eMinus, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",874
      if ( res /= 874) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_muPlus, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",520
      if ( res /= 520) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_H, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1259
      if ( res /= 1259) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_nu_e, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",270
      if ( res /= 270) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_H, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",214
      if ( res /= 214) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",869
      if ( res /= 869) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1365
      if ( res /= 1365) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_g, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1447
      if ( res /= 1447) then
        stop
      end if
      call createParticleConfig(P_u, P_g, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1078
      if ( res /= 1078) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",169
      if ( res /= 169) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_c, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1281
      if ( res /= 1281) then
        stop
      end if
      call createParticleConfig(P_H, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",817
      if ( res /= 817) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_WpPlus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",293
      if ( res /= 293) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghWp, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",58
      if ( res /= 58) then
        stop
      end if
      call createParticleConfig(P_s, P_tAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",535
      if ( res /= 535) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_GPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",281
      if ( res /= 281) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",983
      if ( res /= 983) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",274
      if ( res /= 274) then
        stop
      end if
      call createParticleConfig(P_H, P_WMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",637
      if ( res /= 637) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_tauMinus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",343
      if ( res /= 343) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_H, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",210
      if ( res /= 210) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1040
      if ( res /= 1040) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_WMinus, P_ghAAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",614
      if ( res /= 614) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_nu_muAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",162
      if ( res /= 162) then
        stop
      end if
      call createParticleConfig(P_H, P_Z, P_Z, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",696
      if ( res /= 696) then
        stop
      end if
      call createParticleConfig(P_H, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",636
      if ( res /= 636) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",996
      if ( res /= 996) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",781
      if ( res /= 781) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_WpMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1127
      if ( res /= 1127) then
        stop
      end if
      call createParticleConfig(P_d, P_G0, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",238
      if ( res /= 238) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",747
      if ( res /= 747) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_WPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",571
      if ( res /= 571) then
        stop
      end if
      call createParticleConfig(P_H, P_ghWpAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",863
      if ( res /= 863) then
        stop
      end if
      call createParticleConfig(P_H, P_tauPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",366
      if ( res /= 366) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",316
      if ( res /= 316) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1182
      if ( res /= 1182) then
        stop
      end if
      call createParticleConfig(P_H, P_GMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",918
      if ( res /= 918) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",562
      if ( res /= 562) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",949
      if ( res /= 949) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_WpMinus, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",645
      if ( res /= 645) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",325
      if ( res /= 325) then
        stop
      end if
      call createParticleConfig(P_d, P_WPlus, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",990
      if ( res /= 990) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_u, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",768
      if ( res /= 768) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_s, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",611
      if ( res /= 611) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_ePlus, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",664
      if ( res /= 664) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",681
      if ( res /= 681) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1298
      if ( res /= 1298) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_nu_mu, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",936
      if ( res /= 936) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_cAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1071
      if ( res /= 1071) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",88
      if ( res /= 88) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",312
      if ( res /= 312) then
        stop
      end if
      call createParticleConfig(P_H, P_ghZAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",549
      if ( res /= 549) then
        stop
      end if
      call createParticleConfig(P_G0, P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",246
      if ( res /= 246) then
        stop
      end if
      call createParticleConfig(P_H, P_GPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1132
      if ( res /= 1132) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",757
      if ( res /= 757) then
        stop
      end if
      call createParticleConfig(P_u, P_dAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",772
      if ( res /= 772) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_GPlus, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",627
      if ( res /= 627) then
        stop
      end if
      call createParticleConfig(P_s, P_A, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",78
      if ( res /= 78) then
        stop
      end if
      call createParticleConfig(P_s, P_WpPlus, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",968
      if ( res /= 968) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",229
      if ( res /= 229) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",957
      if ( res /= 957) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_WpPlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",701
      if ( res /= 701) then
        stop
      end if
      call createParticleConfig(P_G0, P_H, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1170
      if ( res /= 1170) then
        stop
      end if
      call createParticleConfig(P_d, P_cAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",644
      if ( res /= 644) then
        stop
      end if
      call createParticleConfig(P_H, P_H, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1018
      if ( res /= 1018) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_dAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1326
      if ( res /= 1326) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_bAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",207
      if ( res /= 207) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_H, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",830
      if ( res /= 830) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_A, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1079
      if ( res /= 1079) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1383
      if ( res /= 1383) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",22
      if ( res /= 22) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",689
      if ( res /= 689) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_G0, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",503
      if ( res /= 503) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_WPlus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1131
      if ( res /= 1131) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_g, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1391
      if ( res /= 1391) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1250
      if ( res /= 1250) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghZAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1061
      if ( res /= 1061) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_nu_eAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1036
      if ( res /= 1036) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Z, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",421
      if ( res /= 421) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1345
      if ( res /= 1345) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",142
      if ( res /= 142) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",551
      if ( res /= 551) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_tau, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1289
      if ( res /= 1289) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_GPlus, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1223
      if ( res /= 1223) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_nu_muAnti, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1309
      if ( res /= 1309) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1327
      if ( res /= 1327) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1031
      if ( res /= 1031) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_c, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",86
      if ( res /= 86) then
        stop
      end if
      call createParticleConfig(P_g, P_uAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1376
      if ( res /= 1376) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_u, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1020
      if ( res /= 1020) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_H, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1336
      if ( res /= 1336) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1222
      if ( res /= 1222) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1083
      if ( res /= 1083) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",17
      if ( res /= 17) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",825
      if ( res /= 825) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_A, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",335
      if ( res /= 335) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_H, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",799
      if ( res /= 799) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_t, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",428
      if ( res /= 428) then
        stop
      end if
      call createParticleConfig(P_H, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",283
      if ( res /= 283) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1173
      if ( res /= 1173) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_sAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",75
      if ( res /= 75) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",875
      if ( res /= 875) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1153
      if ( res /= 1153) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_nu_mu, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1105
      if ( res /= 1105) then
        stop
      end if
      call createParticleConfig(P_ghGAnti, P_g, P_ghG, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",897
      if ( res /= 897) then
        stop
      end if
      call createParticleConfig(P_s, P_cAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1143
      if ( res /= 1143) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",714
      if ( res /= 714) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1138
      if ( res /= 1138) then
        stop
      end if
      call createParticleConfig(P_H, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1062
      if ( res /= 1062) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_WpMinus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",237
      if ( res /= 237) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_b, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1181
      if ( res /= 1181) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",959
      if ( res /= 959) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1351
      if ( res /= 1351) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_b, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1123
      if ( res /= 1123) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",536
      if ( res /= 536) then
        stop
      end if
      call createParticleConfig(P_ghA, P_GPlus, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",173
      if ( res /= 173) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghWm, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",878
      if ( res /= 878) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1363
      if ( res /= 1363) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",739
      if ( res /= 739) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghWmAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1162
      if ( res /= 1162) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",508
      if ( res /= 508) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_uAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",742
      if ( res /= 742) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",422
      if ( res /= 422) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",90
      if ( res /= 90) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghA, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",482
      if ( res /= 482) then
        stop
      end if
      call createParticleConfig(P_G0, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1120
      if ( res /= 1120) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_b, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",725
      if ( res /= 725) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",222
      if ( res /= 222) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_WpMinus, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1186
      if ( res /= 1186) then
        stop
      end if
      call createParticleConfig(P_G0, P_ghWp, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",358
      if ( res /= 358) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_tauPlus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",397
      if ( res /= 397) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",120
      if ( res /= 120) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_tauMinus, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",250
      if ( res /= 250) then
        stop
      end if
      call createParticleConfig(P_t, P_WpMinus, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",838
      if ( res /= 838) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",459
      if ( res /= 459) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_s, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",948
      if ( res /= 948) then
        stop
      end if
      call createParticleConfig(P_t, P_g, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1398
      if ( res /= 1398) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",502
      if ( res /= 502) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1176
      if ( res /= 1176) then
        stop
      end if
      call createParticleConfig(P_c, P_WpMinus, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",930
      if ( res /= 930) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_tAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",524
      if ( res /= 524) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1359
      if ( res /= 1359) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_WPlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",605
      if ( res /= 605) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1066
      if ( res /= 1066) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_WpPlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",338
      if ( res /= 338) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_nu_tau, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",84
      if ( res /= 84) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1055
      if ( res /= 1055) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghWmAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",519
      if ( res /= 519) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",525
      if ( res /= 525) then
        stop
      end if
      call createParticleConfig(P_Z, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1094
      if ( res /= 1094) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",956
      if ( res /= 956) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_mu, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1016
      if ( res /= 1016) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_H, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",750
      if ( res /= 750) then
        stop
      end if
      call createParticleConfig(P_u, P_sAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",624
      if ( res /= 624) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_nu_eAnti, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",271
      if ( res /= 271) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_uAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",755
      if ( res /= 755) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_GMinus, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",103
      if ( res /= 103) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghWp, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",862
      if ( res /= 862) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1095
      if ( res /= 1095) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_t, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",807
      if ( res /= 807) then
        stop
      end if
      call createParticleConfig(P_H, P_GPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",403
      if ( res /= 403) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_A, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1056
      if ( res /= 1056) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghAAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",361
      if ( res /= 361) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",301
      if ( res /= 301) then
        stop
      end if
      call createParticleConfig(P_Z, P_H, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",5
      if ( res /= 5) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",254
      if ( res /= 254) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_c, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",61
      if ( res /= 61) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1021
      if ( res /= 1021) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_t, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",344
      if ( res /= 344) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_H, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",526
      if ( res /= 526) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",690
      if ( res /= 690) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1333
      if ( res /= 1333) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_WpPlus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1129
      if ( res /= 1129) then
        stop
      end if
      call createParticleConfig(P_d, P_sAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",555
      if ( res /= 555) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_eMinus, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",773
      if ( res /= 773) then
        stop
      end if
      call createParticleConfig(P_H, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1436
      if ( res /= 1436) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_H, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1283
      if ( res /= 1283) then
        stop
      end if
      call createParticleConfig(P_H, P_WPlus, P_H, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",488
      if ( res /= 488) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1372
      if ( res /= 1372) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghWpAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",943
      if ( res /= 943) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_Z, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1064
      if ( res /= 1064) then
        stop
      end if
      call createParticleConfig(P_b, P_Z, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",289
      if ( res /= 289) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",82
      if ( res /= 82) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_WPlus, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1236
      if ( res /= 1236) then
        stop
      end if
      call createParticleConfig(P_ghAAnti, P_WMinus, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",554
      if ( res /= 554) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1039
      if ( res /= 1039) then
        stop
      end if
      call createParticleConfig(P_d, P_uAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1088
      if ( res /= 1088) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_nu_muAnti, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1124
      if ( res /= 1124) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_WMinus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",720
      if ( res /= 720) then
        stop
      end if
      call createParticleConfig(P_b, P_tAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1017
      if ( res /= 1017) then
        stop
      end if
      call createParticleConfig(P_H, P_ghZ, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",320
      if ( res /= 320) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_H, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",602
      if ( res /= 602) then
        stop
      end if
      call createParticleConfig(P_ghAAnti, P_ghWp, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",432
      if ( res /= 432) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_WPlus, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",532
      if ( res /= 532) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghA, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",855
      if ( res /= 855) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_WpMinus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1043
      if ( res /= 1043) then
        stop
      end if
      call createParticleConfig(P_H, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",859
      if ( res /= 859) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_WpPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",670
      if ( res /= 670) then
        stop
      end if
      call createParticleConfig(P_G0, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",287
      if ( res /= 287) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_WpMinus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",881
      if ( res /= 881) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_GPlus, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",565
      if ( res /= 565) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_nu_tau, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",506
      if ( res /= 506) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_nu_eAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",472
      if ( res /= 472) then
        stop
      end if
      call createParticleConfig(P_c, P_g, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1388
      if ( res /= 1388) then
        stop
      end if
      call createParticleConfig(P_ghAAnti, P_ghWm, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",69
      if ( res /= 69) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",913
      if ( res /= 913) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_Z, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",23
      if ( res /= 23) then
        stop
      end if
      call createParticleConfig(P_G0, P_dAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",702
      if ( res /= 702) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",304
      if ( res /= 304) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_WpMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",19
      if ( res /= 19) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",474
      if ( res /= 474) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_t, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1261
      if ( res /= 1261) then
        stop
      end if
      call createParticleConfig(P_H, P_H, P_H, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",181
      if ( res /= 181) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_eMinus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",439
      if ( res /= 439) then
        stop
      end if
      call createParticleConfig(P_H, P_GPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",51
      if ( res /= 51) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_WPlus, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",877
      if ( res /= 877) then
        stop
      end if
      call createParticleConfig(P_s, P_g, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1410
      if ( res /= 1410) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_GMinus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",282
      if ( res /= 282) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghZAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",60
      if ( res /= 60) then
        stop
      end if
      call createParticleConfig(P_c, P_WMinus, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",406
      if ( res /= 406) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_tauPlus, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1305
      if ( res /= 1305) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_A, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",475
      if ( res /= 475) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1092
      if ( res /= 1092) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_tauMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",310
      if ( res /= 310) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",955
      if ( res /= 955) then
        stop
      end if
      call createParticleConfig(P_A, P_ghWpAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",546
      if ( res /= 546) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_d, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",581
      if ( res /= 581) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1362
      if ( res /= 1362) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1014
      if ( res /= 1014) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",988
      if ( res /= 988) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",648
      if ( res /= 648) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_tauPlus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",633
      if ( res /= 633) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_Z, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",256
      if ( res /= 256) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_H, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",674
      if ( res /= 674) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",147
      if ( res /= 147) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",925
      if ( res /= 925) then
        stop
      end if
      call createParticleConfig(P_Z, P_H, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",827
      if ( res /= 827) then
        stop
      end if
      call createParticleConfig(P_A, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",223
      if ( res /= 223) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_WpMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1321
      if ( res /= 1321) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_WpPlus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",121
      if ( res /= 121) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",600
      if ( res /= 600) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghWpAnti, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",466
      if ( res /= 466) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_nu_tauAnti, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1013
      if ( res /= 1013) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_g, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1417
      if ( res /= 1417) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_g, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1418
      if ( res /= 1418) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",934
      if ( res /= 934) then
        stop
      end if
      call createParticleConfig(P_Z, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",110
      if ( res /= 110) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghZ, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",13
      if ( res /= 13) then
        stop
      end if
      call createParticleConfig(P_b, P_A, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",575
      if ( res /= 575) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",368
      if ( res /= 368) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_c, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1220
      if ( res /= 1220) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_c, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",280
      if ( res /= 280) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_H, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1284
      if ( res /= 1284) then
        stop
      end if
      call createParticleConfig(P_g, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",464
      if ( res /= 464) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghWp, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",221
      if ( res /= 221) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_H, P_GPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1279
      if ( res /= 1279) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",888
      if ( res /= 888) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_s, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",262
      if ( res /= 262) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_G0, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",208
      if ( res /= 208) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",458
      if ( res /= 458) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",35
      if ( res /= 35) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_d, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",866
      if ( res /= 866) then
        stop
      end if
      call createParticleConfig(P_c, P_WpMinus, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",514
      if ( res /= 514) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_H, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",34
      if ( res /= 34) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",761
      if ( res /= 761) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",944
      if ( res /= 944) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_A, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1122
      if ( res /= 1122) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",67
      if ( res /= 67) then
        stop
      end if
      call createParticleConfig(P_g, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",327
      if ( res /= 327) then
        stop
      end if
      call createParticleConfig(P_g, P_sAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1425
      if ( res /= 1425) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_nu_e, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",53
      if ( res /= 53) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1338
      if ( res /= 1338) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1335
      if ( res /= 1335) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_nu_eAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",813
      if ( res /= 813) then
        stop
      end if
      call createParticleConfig(P_A, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",185
      if ( res /= 185) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_GMinus, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",188
      if ( res /= 188) then
        stop
      end if
      call createParticleConfig(P_b, P_G0, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",253
      if ( res /= 253) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_GMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1026
      if ( res /= 1026) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_s, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1278
      if ( res /= 1278) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_Z, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",700
      if ( res /= 700) then
        stop
      end if
      call createParticleConfig(P_Z, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1076
      if ( res /= 1076) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_WMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",497
      if ( res /= 497) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghZAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1306
      if ( res /= 1306) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",589
      if ( res /= 589) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",839
      if ( res /= 839) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",550
      if ( res /= 550) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WPlus, P_WMinus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",778
      if ( res /= 778) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1008
      if ( res /= 1008) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_WpPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1044
      if ( res /= 1044) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",846
      if ( res /= 846) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghZ, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",52
      if ( res /= 52) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_c, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1387
      if ( res /= 1387) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghWpAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",683
      if ( res /= 683) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_nu_tauAnti, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",694
      if ( res /= 694) then
        stop
      end if
      call createParticleConfig(P_H, P_Z, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",490
      if ( res /= 490) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_s, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1397
      if ( res /= 1397) then
        stop
      end if
      call createParticleConfig(P_s, P_WPlus, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1291
      if ( res /= 1291) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghWp, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1115
      if ( res /= 1115) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",224
      if ( res /= 224) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",914
      if ( res /= 914) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",467
      if ( res /= 467) then
        stop
      end if
      call createParticleConfig(P_H, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",595
      if ( res /= 595) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",795
      if ( res /= 795) then
        stop
      end if
      call createParticleConfig(P_t, P_WpMinus, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1248
      if ( res /= 1248) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghWpAnti, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",419
      if ( res /= 419) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1308
      if ( res /= 1308) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",159
      if ( res /= 159) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",101
      if ( res /= 101) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_b, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",37
      if ( res /= 37) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_H, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1319
      if ( res /= 1319) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghZAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",494
      if ( res /= 494) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",894
      if ( res /= 894) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghWpAnti, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",66
      if ( res /= 66) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_H, P_H, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",127
      if ( res /= 127) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_Z, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",396
      if ( res /= 396) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_cAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",806
      if ( res /= 806) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1046
      if ( res /= 1046) then
        stop
      end if
      call createParticleConfig(P_u, P_WMinus, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",376
      if ( res /= 376) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",680
      if ( res /= 680) then
        stop
      end if
      call createParticleConfig(P_ghG, P_g, P_ghGAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1194
      if ( res /= 1194) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_WMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1257
      if ( res /= 1257) then
        stop
      end if
      call createParticleConfig(P_H, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",139
      if ( res /= 139) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_Z, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",718
      if ( res /= 718) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_nu_mu, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",557
      if ( res /= 557) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",999
      if ( res /= 999) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1271
      if ( res /= 1271) then
        stop
      end if
      call createParticleConfig(P_A, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1324
      if ( res /= 1324) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1367
      if ( res /= 1367) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_nu_tauAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",537
      if ( res /= 537) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_WMinus, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1247
      if ( res /= 1247) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_WpMinus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",951
      if ( res /= 951) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_tauPlus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1201
      if ( res /= 1201) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghZ, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",138
      if ( res /= 138) then
        stop
      end if
      call createParticleConfig(P_t, P_bAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",445
      if ( res /= 445) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_GPlus, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",165
      if ( res /= 165) then
        stop
      end if
      call createParticleConfig(P_Z, P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",762
      if ( res /= 762) then
        stop
      end if
      call createParticleConfig(P_G0, P_H, P_H, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",460
      if ( res /= 460) then
        stop
      end if
      call createParticleConfig(P_g, P_t, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1379
      if ( res /= 1379) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_H, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1317
      if ( res /= 1317) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghWpAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",190
      if ( res /= 190) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",161
      if ( res /= 161) then
        stop
      end if
      call createParticleConfig(P_H, P_WMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",265
      if ( res /= 265) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",111
      if ( res /= 111) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1137
      if ( res /= 1137) then
        stop
      end if
      call createParticleConfig(P_g, P_c, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1444
      if ( res /= 1444) then
        stop
      end if
      call createParticleConfig(P_G0, P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",206
      if ( res /= 206) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1350
      if ( res /= 1350) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_t, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",794
      if ( res /= 794) then
        stop
      end if
      call createParticleConfig(P_G0, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1159
      if ( res /= 1159) then
        stop
      end if
      call createParticleConfig(P_g, P_ghG, P_ghGAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",623
      if ( res /= 623) then
        stop
      end if
      call createParticleConfig(P_Z, P_H, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1037
      if ( res /= 1037) then
        stop
      end if
      call createParticleConfig(P_ghAAnti, P_WPlus, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1107
      if ( res /= 1107) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1344
      if ( res /= 1344) then
        stop
      end if
      call createParticleConfig(P_Z, P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",202
      if ( res /= 202) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_sAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",766
      if ( res /= 766) then
        stop
      end if
      call createParticleConfig(P_H, P_WPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",152
      if ( res /= 152) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_d, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1377
      if ( res /= 1377) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1118
      if ( res /= 1118) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_GMinus, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",730
      if ( res /= 730) then
        stop
      end if
      call createParticleConfig(P_c, P_uAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1428
      if ( res /= 1428) then
        stop
      end if
      call createParticleConfig(P_s, P_G0, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",273
      if ( res /= 273) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",150
      if ( res /= 150) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghWp, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",98
      if ( res /= 98) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",418
      if ( res /= 418) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",826
      if ( res /= 826) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_tauMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1072
      if ( res /= 1072) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",922
      if ( res /= 922) then
        stop
      end if
      call createParticleConfig(P_d, P_A, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",342
      if ( res /= 342) then
        stop
      end if
      call createParticleConfig(P_t, P_g, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1435
      if ( res /= 1435) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1167
      if ( res /= 1167) then
        stop
      end if
      call createParticleConfig(P_g, P_dAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1442
      if ( res /= 1442) then
        stop
      end if
      call createParticleConfig(P_g, P_bAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1390
      if ( res /= 1390) then
        stop
      end if
      call createParticleConfig(P_H, P_H, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",456
      if ( res /= 456) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",723
      if ( res /= 723) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",962
      if ( res /= 962) then
        stop
      end if
      call createParticleConfig(P_H, P_WPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1273
      if ( res /= 1273) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",170
      if ( res /= 170) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_H, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1121
      if ( res /= 1121) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_A, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",679
      if ( res /= 679) then
        stop
      end if
      call createParticleConfig(P_d, P_sAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1412
      if ( res /= 1412) then
        stop
      end if
      call createParticleConfig(P_c, P_WMinus, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",448
      if ( res /= 448) then
        stop
      end if
      call createParticleConfig(P_u, P_Z, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",569
      if ( res /= 569) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",559
      if ( res /= 559) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",923
      if ( res /= 923) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_s, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",46
      if ( res /= 46) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghA, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",642
      if ( res /= 642) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_muAnti, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",891
      if ( res /= 891) then
        stop
      end if
      call createParticleConfig(P_Z, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1282
      if ( res /= 1282) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_H, P_H, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",843
      if ( res /= 843) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_nu_tauAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",49
      if ( res /= 49) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",143
      if ( res /= 143) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_H, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1199
      if ( res /= 1199) then
        stop
      end if
      call createParticleConfig(P_Z, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",31
      if ( res /= 31) then
        stop
      end if
      call createParticleConfig(P_b, P_cAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",390
      if ( res /= 390) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",749
      if ( res /= 749) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",447
      if ( res /= 447) then
        stop
      end if
      call createParticleConfig(P_A, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",230
      if ( res /= 230) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",872
      if ( res /= 872) then
        stop
      end if
      call createParticleConfig(P_A, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",785
      if ( res /= 785) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",106
      if ( res /= 106) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",360
      if ( res /= 360) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_nu_tauAnti, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1190
      if ( res /= 1190) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",244
      if ( res /= 244) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_muMinus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1169
      if ( res /= 1169) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_H, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",523
      if ( res /= 523) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_nu_eAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",149
      if ( res /= 149) then
        stop
      end if
      call createParticleConfig(P_s, P_g, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",434
      if ( res /= 434) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",99
      if ( res /= 99) then
        stop
      end if
      call createParticleConfig(P_u, P_sAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",779
      if ( res /= 779) then
        stop
      end if
      call createParticleConfig(P_b, P_g, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1380
      if ( res /= 1380) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",511
      if ( res /= 511) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_bAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",194
      if ( res /= 194) then
        stop
      end if
      call createParticleConfig(P_d, P_uAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",414
      if ( res /= 414) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_GMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",708
      if ( res /= 708) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_WPlus, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1135
      if ( res /= 1135) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",982
      if ( res /= 982) then
        stop
      end if
      call createParticleConfig(P_H, P_s, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",285
      if ( res /= 285) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1369
      if ( res /= 1369) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",880
      if ( res /= 880) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1276
      if ( res /= 1276) then
        stop
      end if
      call createParticleConfig(P_g, P_H, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1406
      if ( res /= 1406) then
        stop
      end if
      call createParticleConfig(P_H, P_GPlus, P_GMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",226
      if ( res /= 226) then
        stop
      end if
      call createParticleConfig(P_Z, P_ghWm, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",134
      if ( res /= 134) then
        stop
      end if
      call createParticleConfig(P_g, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",743
      if ( res /= 743) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_g, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",573
      if ( res /= 573) then
        stop
      end if
      call createParticleConfig(P_A, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",584
      if ( res /= 584) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",16
      if ( res /= 16) then
        stop
      end if
      call createParticleConfig(P_g, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",796
      if ( res /= 796) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",765
      if ( res /= 765) then
        stop
      end if
      call createParticleConfig(P_H, P_GMinus, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1262
      if ( res /= 1262) then
        stop
      end if
      call createParticleConfig(P_d, P_uAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",798
      if ( res /= 798) then
        stop
      end if
      call createParticleConfig(P_H, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1108
      if ( res /= 1108) then
        stop
      end if
      call createParticleConfig(P_H, P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",267
      if ( res /= 267) then
        stop
      end if
      call createParticleConfig(P_t, P_g, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1144
      if ( res /= 1144) then
        stop
      end if
      call createParticleConfig(P_Z, P_ghWmAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",412
      if ( res /= 412) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghA, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",668
      if ( res /= 668) then
        stop
      end if
      call createParticleConfig(P_ghG, P_ghGAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",28
      if ( res /= 28) then
        stop
      end if
      call createParticleConfig(P_g, P_uAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1431
      if ( res /= 1431) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",315
      if ( res /= 315) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_nu_tau, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",183
      if ( res /= 183) then
        stop
      end if
      call createParticleConfig(P_H, P_GMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",64
      if ( res /= 64) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",10
      if ( res /= 10) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",42
      if ( res /= 42) then
        stop
      end if
      call createParticleConfig(P_ghA, P_WPlus, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",590
      if ( res /= 590) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_WpMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1331
      if ( res /= 1331) then
        stop
      end if
      call createParticleConfig(P_G0, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1141
      if ( res /= 1141) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1357
      if ( res /= 1357) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1147
      if ( res /= 1147) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1003
      if ( res /= 1003) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_G0, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1325
      if ( res /= 1325) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",530
      if ( res /= 530) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",109
      if ( res /= 109) then
        stop
      end if
      call createParticleConfig(P_A, P_ghWmAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",568
      if ( res /= 568) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_tauPlus, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",157
      if ( res /= 157) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_WMinus, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",531
      if ( res /= 531) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_eMinus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",885
      if ( res /= 885) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghWm, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1
      if ( res /= 1) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",995
      if ( res /= 995) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_eMinus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",618
      if ( res /= 618) then
        stop
      end if
      call createParticleConfig(P_Z, P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",635
      if ( res /= 635) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",87
      if ( res /= 87) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",192
      if ( res /= 192) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",369
      if ( res /= 369) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1313
      if ( res /= 1313) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_WpPlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",141
      if ( res /= 141) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1180
      if ( res /= 1180) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_nu_e, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1025
      if ( res /= 1025) then
        stop
      end if
      call createParticleConfig(P_H, P_WMinus, P_H, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",462
      if ( res /= 462) then
        stop
      end if
      call createParticleConfig(P_g, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1100
      if ( res /= 1100) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_A, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1146
      if ( res /= 1146) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_WpPlus, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",303
      if ( res /= 303) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_Z, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",939
      if ( res /= 939) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_WpPlus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",738
      if ( res /= 738) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",748
      if ( res /= 748) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",688
      if ( res /= 688) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",770
      if ( res /= 770) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",653
      if ( res /= 653) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",468
      if ( res /= 468) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_d, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",24
      if ( res /= 24) then
        stop
      end if
      call createParticleConfig(P_H, P_Z, P_H, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",240
      if ( res /= 240) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_tAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",975
      if ( res /= 975) then
        stop
      end if
      call createParticleConfig(P_g, P_d, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1440
      if ( res /= 1440) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_uAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",166
      if ( res /= 166) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_ePlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",480
      if ( res /= 480) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GPlus, P_WMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",211
      if ( res /= 211) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",831
      if ( res /= 831) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ePlus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",969
      if ( res /= 969) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",848
      if ( res /= 848) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Z, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1172
      if ( res /= 1172) then
        stop
      end if
      call createParticleConfig(P_s, P_dAnti, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",234
      if ( res /= 234) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghAAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",193
      if ( res /= 193) then
        stop
      end if
      call createParticleConfig(P_b, P_uAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1175
      if ( res /= 1175) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",275
      if ( res /= 275) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghZAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",18
      if ( res /= 18) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1084
      if ( res /= 1084) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_sAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",125
      if ( res /= 125) then
        stop
      end if
      call createParticleConfig(P_u, P_GMinus, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",541
      if ( res /= 541) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_H, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",108
      if ( res /= 108) then
        stop
      end if
      call createParticleConfig(P_A, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",671
      if ( res /= 671) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_muPlus, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",916
      if ( res /= 916) then
        stop
      end if
      call createParticleConfig(P_Z, P_ghWp, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",818
      if ( res /= 818) then
        stop
      end if
      call createParticleConfig(P_d, P_WpPlus, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",842
      if ( res /= 842) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_u, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",172
      if ( res /= 172) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1024
      if ( res /= 1024) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_WpMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1085
      if ( res /= 1085) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_tauPlus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",596
      if ( res /= 596) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_H, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",79
      if ( res /= 79) then
        stop
      end if
      call createParticleConfig(P_u, P_H, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1104
      if ( res /= 1104) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_H, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",195
      if ( res /= 195) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghWm, P_ghAAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",763
      if ( res /= 763) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_s, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",14
      if ( res /= 14) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",80
      if ( res /= 80) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_ePlus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1126
      if ( res /= 1126) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_H, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",492
      if ( res /= 492) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",465
      if ( res /= 465) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_u, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",295
      if ( res /= 295) then
        stop
      end if
      call createParticleConfig(P_b, P_g, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1414
      if ( res /= 1414) then
        stop
      end if
      call createParticleConfig(P_Z, P_ghWpAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1111
      if ( res /= 1111) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1353
      if ( res /= 1353) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",306
      if ( res /= 306) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1089
      if ( res /= 1089) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",736
      if ( res /= 736) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_G0, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1086
      if ( res /= 1086) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",851
      if ( res /= 851) then
        stop
      end if
      call createParticleConfig(P_ghGAnti, P_ghG, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",430
      if ( res /= 430) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_Z, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",124
      if ( res /= 124) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",279
      if ( res /= 279) then
        stop
      end if
      call createParticleConfig(P_b, P_WpPlus, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",860
      if ( res /= 860) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_c, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",184
      if ( res /= 184) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",104
      if ( res /= 104) then
        stop
      end if
      call createParticleConfig(P_c, P_bAnti, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1269
      if ( res /= 1269) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghWmAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1161
      if ( res /= 1161) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1197
      if ( res /= 1197) then
        stop
      end if
      call createParticleConfig(P_g, P_g, P_g, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",591
      if ( res /= 591) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_WpMinus, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",30
      if ( res /= 30) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_b, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1166
      if ( res /= 1166) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_u, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",26
      if ( res /= 26) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_eMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",997
      if ( res /= 997) then
        stop
      end if
      call createParticleConfig(P_H, P_Z, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",556
      if ( res /= 556) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_tauPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1290
      if ( res /= 1290) then
        stop
      end if
      call createParticleConfig(P_H, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1342
      if ( res /= 1342) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_WMinus, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1272
      if ( res /= 1272) then
        stop
      end if
      call createParticleConfig(P_d, P_g, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1423
      if ( res /= 1423) then
        stop
      end if
      call createParticleConfig(P_t, P_WMinus, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",716
      if ( res /= 716) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_cAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",837
      if ( res /= 837) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_t, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",677
      if ( res /= 677) then
        stop
      end if
      call createParticleConfig(P_H, P_d, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1216
      if ( res /= 1216) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_H, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1178
      if ( res /= 1178) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_u, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1106
      if ( res /= 1106) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghWp, P_ghAAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",973
      if ( res /= 973) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_WpPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",383
      if ( res /= 383) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_c, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",367
      if ( res /= 367) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_c, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",578
      if ( res /= 578) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Z, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1206
      if ( res /= 1206) then
        stop
      end if
      call createParticleConfig(P_H, P_GMinus, P_H, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",792
      if ( res /= 792) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_c, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",317
      if ( res /= 317) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",65
      if ( res /= 65) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1221
      if ( res /= 1221) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_A, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",528
      if ( res /= 528) then
        stop
      end if
      call createParticleConfig(P_G0, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1311
      if ( res /= 1311) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",517
      if ( res /= 517) then
        stop
      end if
      call createParticleConfig(P_g, P_dAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1415
      if ( res /= 1415) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_d, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1091
      if ( res /= 1091) then
        stop
      end if
      call createParticleConfig(P_H, P_WMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1312
      if ( res /= 1312) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_g, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",760
      if ( res /= 760) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_d, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",861
      if ( res /= 861) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",326
      if ( res /= 326) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",386
      if ( res /= 386) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_H, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",978
      if ( res /= 978) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_WpMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1045
      if ( res /= 1045) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",236
      if ( res /= 236) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_WPlus, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",672
      if ( res /= 672) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",217
      if ( res /= 217) then
        stop
      end if
      call createParticleConfig(P_g, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",119
      if ( res /= 119) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_s, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",876
      if ( res /= 876) then
        stop
      end if
      call createParticleConfig(P_Z, P_H, P_Z, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",659
      if ( res /= 659) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_G0, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",604
      if ( res /= 604) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_bAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1171
      if ( res /= 1171) then
        stop
      end if
      call createParticleConfig(P_c, P_tAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1409
      if ( res /= 1409) then
        stop
      end if
      call createParticleConfig(P_H, P_ghWmAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",455
      if ( res /= 455) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_GMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1332
      if ( res /= 1332) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_muPlus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",515
      if ( res /= 515) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_WPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",797
      if ( res /= 797) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_GPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",21
      if ( res /= 21) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghAAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",868
      if ( res /= 868) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1051
      if ( res /= 1051) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghWm, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",856
      if ( res /= 856) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_Z, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",470
      if ( res /= 470) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_muMinus, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",857
      if ( res /= 857) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_Z, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",479
      if ( res /= 479) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_nu_eAnti, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",299
      if ( res /= 299) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_GMinus, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",377
      if ( res /= 377) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1243
      if ( res /= 1243) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghWpAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",890
      if ( res /= 890) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_u, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1441
      if ( res /= 1441) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_uAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",128
      if ( res /= 128) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_H, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",186
      if ( res /= 186) then
        stop
      end if
      call createParticleConfig(P_Z, P_cAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",808
      if ( res /= 808) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_G0, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",527
      if ( res /= 527) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_WPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",239
      if ( res /= 239) then
        stop
      end if
      call createParticleConfig(P_H, P_G0, P_G0, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1233
      if ( res /= 1233) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_WpMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1189
      if ( res /= 1189) then
        stop
      end if
      call createParticleConfig(P_d, P_bAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1416
      if ( res /= 1416) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_H, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1334
      if ( res /= 1334) then
        stop
      end if
      call createParticleConfig(P_Z, P_H, P_H, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",954
      if ( res /= 954) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1063
      if ( res /= 1063) then
        stop
      end if
      call createParticleConfig(P_s, P_cAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",63
      if ( res /= 63) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",348
      if ( res /= 348) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_nu_mu, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1142
      if ( res /= 1142) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_nu_eAnti, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",991
      if ( res /= 991) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",72
      if ( res /= 72) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghA, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",292
      if ( res /= 292) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_WpPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",426
      if ( res /= 426) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_G0, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1322
      if ( res /= 1322) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_GMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",899
      if ( res /= 899) then
        stop
      end if
      call createParticleConfig(P_G0, P_ghWpAnti, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",438
      if ( res /= 438) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_nu_e, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",987
      if ( res /= 987) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ePlus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",423
      if ( res /= 423) then
        stop
      end if
      call createParticleConfig(P_b, P_dAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1384
      if ( res /= 1384) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_g, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1433
      if ( res /= 1433) then
        stop
      end if
      call createParticleConfig(P_t, P_dAnti, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1267
      if ( res /= 1267) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_GPlus, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",802
      if ( res /= 802) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",669
      if ( res /= 669) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_G0, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",753
      if ( res /= 753) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_nu_mu, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",196
      if ( res /= 196) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1148
      if ( res /= 1148) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_eAnti, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",812
      if ( res /= 812) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghWp, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",775
      if ( res /= 775) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_Z, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",704
      if ( res /= 704) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_u, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",321
      if ( res /= 321) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",416
      if ( res /= 416) then
        stop
      end if
      call createParticleConfig(P_g, P_cAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1392
      if ( res /= 1392) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1240
      if ( res /= 1240) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_WpPlus, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",129
      if ( res /= 129) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",349
      if ( res /= 349) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1145
      if ( res /= 1145) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_WpPlus, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",713
      if ( res /= 713) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_WMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",235
      if ( res /= 235) then
        stop
      end if
      call createParticleConfig(P_d, P_WPlus, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",76
      if ( res /= 76) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_nu_tauAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1307
      if ( res /= 1307) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1114
      if ( res /= 1114) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",156
      if ( res /= 156) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_H, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",788
      if ( res /= 788) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_WpMinus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",357
      if ( res /= 357) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",892
      if ( res /= 892) then
        stop
      end if
      call createParticleConfig(P_s, P_H, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",4
      if ( res /= 4) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_Z, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1028
      if ( res /= 1028) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_uAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",115
      if ( res /= 115) then
        stop
      end if
      call createParticleConfig(P_G0, P_H, P_G0, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",979
      if ( res /= 979) then
        stop
      end if
      call createParticleConfig(P_Z, P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1179
      if ( res /= 1179) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_H, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1130
      if ( res /= 1130) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1080
      if ( res /= 1080) then
        stop
      end if
      call createParticleConfig(P_b, P_tAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1041
      if ( res /= 1041) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",324
      if ( res /= 324) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_GMinus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",113
      if ( res /= 113) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_A, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",436
      if ( res /= 436) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1348
      if ( res /= 1348) then
        stop
      end if
      call createParticleConfig(P_H, P_GMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",493
      if ( res /= 493) then
        stop
      end if
      call createParticleConfig(P_Z, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",444
      if ( res /= 444) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_muMinus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",461
      if ( res /= 461) then
        stop
      end if
      call createParticleConfig(P_b, P_tAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",970
      if ( res /= 970) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_WpMinus, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",630
      if ( res /= 630) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_nu_tau, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",309
      if ( res /= 309) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_GPlus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",933
      if ( res /= 933) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",284
      if ( res /= 284) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",971
      if ( res /= 971) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1366
      if ( res /= 1366) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_g, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1432
      if ( res /= 1432) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_WPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",619
      if ( res /= 619) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_d, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1204
      if ( res /= 1204) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_b, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1296
      if ( res /= 1296) then
        stop
      end if
      call createParticleConfig(P_g, P_tAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1402
      if ( res /= 1402) then
        stop
      end if
      call createParticleConfig(P_u, P_dAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",9
      if ( res /= 9) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",356
      if ( res /= 356) then
        stop
      end if
      call createParticleConfig(P_s, P_cAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",854
      if ( res /= 854) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_s, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",652
      if ( res /= 652) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_nu_mu, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",263
      if ( res /= 263) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_t, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1394
      if ( res /= 1394) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_c, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",251
      if ( res /= 251) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_t, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",582
      if ( res /= 582) then
        stop
      end if
      call createParticleConfig(P_H, P_WMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",429
      if ( res /= 429) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",661
      if ( res /= 661) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_H, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",639
      if ( res /= 639) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_bAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",322
      if ( res /= 322) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",647
      if ( res /= 647) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_WMinus, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",727
      if ( res /= 727) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",286
      if ( res /= 286) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",870
      if ( res /= 870) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_WpMinus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",902
      if ( res /= 902) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",212
      if ( res /= 212) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_GMinus, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",787
      if ( res /= 787) then
        stop
      end if
      call createParticleConfig(P_H, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1268
      if ( res /= 1268) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",354
      if ( res /= 354) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_cAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",151
      if ( res /= 151) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_ghZ, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",790
      if ( res /= 790) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_H, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",300
      if ( res /= 300) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghA, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1224
      if ( res /= 1224) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_cAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",140
      if ( res /= 140) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_GPlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",154
      if ( res /= 154) then
        stop
      end if
      call createParticleConfig(P_Z, P_H, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",443
      if ( res /= 443) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",25
      if ( res /= 25) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_ghWm, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1011
      if ( res /= 1011) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",36
      if ( res /= 36) then
        stop
      end if
      call createParticleConfig(P_g, P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",626
      if ( res /= 626) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_d, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1329
      if ( res /= 1329) then
        stop
      end if
      call createParticleConfig(P_ghA, P_WMinus, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1082
      if ( res /= 1082) then
        stop
      end if
      call createParticleConfig(P_H, P_WPlus, P_WMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1004
      if ( res /= 1004) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_u, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",805
      if ( res /= 805) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_muPlus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",529
      if ( res /= 529) then
        stop
      end if
      call createParticleConfig(P_u, P_GMinus, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1297
      if ( res /= 1297) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_WpPlus, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",961
      if ( res /= 961) then
        stop
      end if
      call createParticleConfig(P_ghA, P_ghWmAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",179
      if ( res /= 179) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1214
      if ( res /= 1214) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_A, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1294
      if ( res /= 1294) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_sAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",588
      if ( res /= 588) then
        stop
      end if
      call createParticleConfig(P_ghA, P_ghWpAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1074
      if ( res /= 1074) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghWmAnti, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",452
      if ( res /= 452) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Z, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",220
      if ( res /= 220) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1001
      if ( res /= 1001) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_WMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",200
      if ( res /= 200) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",473
      if ( res /= 473) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_muPlus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",811
      if ( res /= 811) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_d, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",249
      if ( res /= 249) then
        stop
      end if
      call createParticleConfig(P_G0, P_muPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",486
      if ( res /= 486) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",629
      if ( res /= 629) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_H, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1068
      if ( res /= 1068) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghZ, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",572
      if ( res /= 572) then
        stop
      end if
      call createParticleConfig(P_b, P_GPlus, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",522
      if ( res /= 522) then
        stop
      end if
      call createParticleConfig(P_u, P_sAnti, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",381
      if ( res /= 381) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1270
      if ( res /= 1270) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",744
      if ( res /= 744) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_GPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",998
      if ( res /= 998) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",548
      if ( res /= 548) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_H, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",844
      if ( res /= 844) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",657
      if ( res /= 657) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_t, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1437
      if ( res /= 1437) then
        stop
      end if
      call createParticleConfig(P_b, P_WPlus, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",580
      if ( res /= 580) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_g, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1395
      if ( res /= 1395) then
        stop
      end if
      call createParticleConfig(P_u, P_g, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1378
      if ( res /= 1378) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1355
      if ( res /= 1355) then
        stop
      end if
      call createParticleConfig(P_c, P_dAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",400
      if ( res /= 400) then
        stop
      end if
      call createParticleConfig(P_G0, P_GPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",227
      if ( res /= 227) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1364
      if ( res /= 1364) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1346
      if ( res /= 1346) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WMinus, P_WPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",437
      if ( res /= 437) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_nu_mu, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",740
      if ( res /= 740) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_g, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1229
      if ( res /= 1229) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",62
      if ( res /= 62) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",187
      if ( res /= 187) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_A, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",731
      if ( res /= 731) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_tauPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",935
      if ( res /= 935) then
        stop
      end if
      call createParticleConfig(P_g, P_t, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1382
      if ( res /= 1382) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghWm, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",758
      if ( res /= 758) then
        stop
      end if
      call createParticleConfig(P_b, P_H, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1232
      if ( res /= 1232) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_nu_tauAnti, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",513
      if ( res /= 513) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_nu_tau, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",658
      if ( res /= 658) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",454
      if ( res /= 454) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",972
      if ( res /= 972) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_ePlus, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",40
      if ( res /= 40) then
        stop
      end if
      call createParticleConfig(P_H, P_ghWp, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",706
      if ( res /= 706) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_d, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1286
      if ( res /= 1286) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_c, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",655
      if ( res /= 655) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",0
      if ( res /= 0) then
        stop
      end if
      call createParticleConfig(P_c, P_G0, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",341
      if ( res /= 341) then
        stop
      end if
      call createParticleConfig(P_H, P_GMinus, P_GPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",145
      if ( res /= 145) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_muPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",420
      if ( res /= 420) then
        stop
      end if
      call createParticleConfig(P_b, P_sAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1443
      if ( res /= 1443) then
        stop
      end if
      call createParticleConfig(P_Z, P_H, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",516
      if ( res /= 516) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1225
      if ( res /= 1225) then
        stop
      end if
      call createParticleConfig(P_G0, P_d, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1155
      if ( res /= 1155) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_muMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",380
      if ( res /= 380) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_tauMinus, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",821
      if ( res /= 821) then
        stop
      end if
      call createParticleConfig(P_H, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",924
      if ( res /= 924) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_H, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1310
      if ( res /= 1310) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_d, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",616
      if ( res /= 616) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",189
      if ( res /= 189) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1087
      if ( res /= 1087) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_H, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1277
      if ( res /= 1277) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1192
      if ( res /= 1192) then
        stop
      end if
      call createParticleConfig(P_A, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",114
      if ( res /= 114) then
        stop
      end if
      call createParticleConfig(P_Z, P_H, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1230
      if ( res /= 1230) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1133
      if ( res /= 1133) then
        stop
      end if
      call createParticleConfig(P_c, P_sAnti, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",963
      if ( res /= 963) then
        stop
      end if
      call createParticleConfig(P_H, P_WMinus, P_WPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",784
      if ( res /= 784) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_GPlus, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1295
      if ( res /= 1295) then
        stop
      end if
      call createParticleConfig(P_g, P_d, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1401
      if ( res /= 1401) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GPlus, P_GMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1073
      if ( res /= 1073) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1358
      if ( res /= 1358) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",334
      if ( res /= 334) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_nu_tauAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",485
      if ( res /= 485) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",191
      if ( res /= 191) then
        stop
      end if
      call createParticleConfig(P_t, P_uAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1404
      if ( res /= 1404) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",118
      if ( res /= 118) then
        stop
      end if
      call createParticleConfig(P_g, P_u, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1400
      if ( res /= 1400) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_WpMinus, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",451
      if ( res /= 451) then
        stop
      end if
      call createParticleConfig(P_H, P_tAnti, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",442
      if ( res /= 442) then
        stop
      end if
      call createParticleConfig(P_t, P_G0, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1213
      if ( res /= 1213) then
        stop
      end if
      call createParticleConfig(P_H, P_H, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",453
      if ( res /= 453) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_H, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",946
      if ( res /= 946) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_H, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",487
      if ( res /= 487) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1314
      if ( res /= 1314) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_tauMinus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1110
      if ( res /= 1110) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_tAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1012
      if ( res /= 1012) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_H, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",986
      if ( res /= 986) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_b, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",879
      if ( res /= 879) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_WPlus, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",592
      if ( res /= 592) then
        stop
      end if
      call createParticleConfig(P_t, P_H, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",38
      if ( res /= 38) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_H, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",375
      if ( res /= 375) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_nu_eAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",932
      if ( res /= 932) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",518
      if ( res /= 518) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",603
      if ( res /= 603) then
        stop
      end if
      call createParticleConfig(P_t, P_GMinus, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",783
      if ( res /= 783) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_WpMinus, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",737
      if ( res /= 737) then
        stop
      end if
      call createParticleConfig(P_H, P_G0, P_H, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1191
      if ( res /= 1191) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_WMinus, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",752
      if ( res /= 752) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1354
      if ( res /= 1354) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_WMinus, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1254
      if ( res /= 1254) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghZAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",836
      if ( res /= 836) then
        stop
      end if
      call createParticleConfig(P_s, P_G0, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",803
      if ( res /= 803) then
        stop
      end if
      call createParticleConfig(P_H, P_uAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",840
      if ( res /= 840) then
        stop
      end if
      call createParticleConfig(P_u, P_A, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",48
      if ( res /= 48) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghWmAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",882
      if ( res /= 882) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_WpPlus, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",561
      if ( res /= 561) then
        stop
      end if
      call createParticleConfig(P_A, P_u, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",609
      if ( res /= 609) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_ghZ, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1315
      if ( res /= 1315) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",599
      if ( res /= 599) then
        stop
      end if
      call createParticleConfig(P_ghA, P_ghWpAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",347
      if ( res /= 347) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1160
      if ( res /= 1160) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1337
      if ( res /= 1337) then
        stop
      end if
      call createParticleConfig(P_G0, P_ghWm, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",816
      if ( res /= 816) then
        stop
      end if
      call createParticleConfig(P_G0, P_A, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",398
      if ( res /= 398) then
        stop
      end if
      call createParticleConfig(P_s, P_uAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1099
      if ( res /= 1099) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_H, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",257
      if ( res /= 257) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_GMinus, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",352
      if ( res /= 352) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",483
      if ( res /= 483) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_ghWpAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",631
      if ( res /= 631) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",415
      if ( res /= 415) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",545
      if ( res /= 545) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",974
      if ( res /= 974) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_WPlus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1318
      if ( res /= 1318) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1150
      if ( res /= 1150) then
        stop
      end if
      call createParticleConfig(P_G0, P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",291
      if ( res /= 291) then
        stop
      end if
      call createParticleConfig(P_nu_mu, P_muPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",160
      if ( res /= 160) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_A, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",177
      if ( res /= 177) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_H, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",767
      if ( res /= 767) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_GMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",8
      if ( res /= 8) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_G0, P_G0, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",268
      if ( res /= 268) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_muMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",355
      if ( res /= 355) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_s, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",791
      if ( res /= 791) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1285
      if ( res /= 1285) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_A, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",407
      if ( res /= 407) then
        stop
      end if
      call createParticleConfig(P_H, P_GPlus, P_Z, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",215
      if ( res /= 215) then
        stop
      end if
      call createParticleConfig(P_Z, P_A, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1320
      if ( res /= 1320) then
        stop
      end if
      call createParticleConfig(P_H, P_ghWm, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1193
      if ( res /= 1193) then
        stop
      end if
      call createParticleConfig(P_g, P_b, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1408
      if ( res /= 1408) then
        stop
      end if
      call createParticleConfig(P_A, P_A, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",734
      if ( res /= 734) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_u, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",463
      if ( res /= 463) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",504
      if ( res /= 504) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_t, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",27
      if ( res /= 27) then
        stop
      end if
      call createParticleConfig(P_ghWp, P_G0, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",873
      if ( res /= 873) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",992
      if ( res /= 992) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_muMinus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1207
      if ( res /= 1207) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_nu_tau, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",895
      if ( res /= 895) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_A, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",845
      if ( res /= 845) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",364
      if ( res /= 364) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_WMinus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",489
      if ( res /= 489) then
        stop
      end if
      call createParticleConfig(P_G0, P_s, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1195
      if ( res /= 1195) then
        stop
      end if
      call createParticleConfig(P_u, P_WMinus, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",296
      if ( res /= 296) then
        stop
      end if
      call createParticleConfig(P_Z, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",673
      if ( res /= 673) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1293
      if ( res /= 1293) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_WpPlus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",359
      if ( res /= 359) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",330
      if ( res /= 330) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_WMinus, P_nu_e, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",105
      if ( res /= 105) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_H, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1097
      if ( res /= 1097) then
        stop
      end if
      call createParticleConfig(P_d, P_dAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",613
      if ( res /= 613) then
        stop
      end if
      call createParticleConfig(P_tauMinus, P_nu_tauAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",621
      if ( res /= 621) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1065
      if ( res /= 1065) then
        stop
      end if
      call createParticleConfig(P_g, P_s, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1381
      if ( res /= 1381) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",171
      if ( res /= 171) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1288
      if ( res /= 1288) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",612
      if ( res /= 612) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_GMinus, P_ghA, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1185
      if ( res /= 1185) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WPlus, P_WMinus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",597
      if ( res /= 597) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_H, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",213
      if ( res /= 213) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_eMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",89
      if ( res /= 89) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_ghWm, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",646
      if ( res /= 646) then
        stop
      end if
      call createParticleConfig(P_u, P_WpMinus, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",563
      if ( res /= 563) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_WMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",741
      if ( res /= 741) then
        stop
      end if
      call createParticleConfig(P_Z, P_WPlus, P_H, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",904
      if ( res /= 904) then
        stop
      end if
      call createParticleConfig(P_g, P_c, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1430
      if ( res /= 1430) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_WMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",769
      if ( res /= 769) then
        stop
      end if
      call createParticleConfig(P_c, P_g, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",336
      if ( res /= 336) then
        stop
      end if
      call createParticleConfig(P_c, P_cAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",776
      if ( res /= 776) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",329
      if ( res /= 329) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1113
      if ( res /= 1113) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",261
      if ( res /= 261) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_Z, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",499
      if ( res /= 499) then
        stop
      end if
      call createParticleConfig(P_u, P_bAnti, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",505
      if ( res /= 505) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_nu_mu, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",710
      if ( res /= 710) then
        stop
      end if
      call createParticleConfig(P_A, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",323
      if ( res /= 323) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",346
      if ( res /= 346) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",314
      if ( res /= 314) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_WMinus, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",97
      if ( res /= 97) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",883
      if ( res /= 883) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_tAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1093
      if ( res /= 1093) then
        stop
      end if
      call createParticleConfig(P_H, P_H, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",660
      if ( res /= 660) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_ghZ, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1227
      if ( res /= 1227) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_WPlus, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",401
      if ( res /= 401) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",131
      if ( res /= 131) then
        stop
      end if
      call createParticleConfig(P_d, P_tAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1242
      if ( res /= 1242) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_H, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",71
      if ( res /= 71) then
        stop
      end if
      call createParticleConfig(P_s, P_bAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1385
      if ( res /= 1385) then
        stop
      end if
      call createParticleConfig(P_g, P_bAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1427
      if ( res /= 1427) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_nu_muAnti, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",225
      if ( res /= 225) then
        stop
      end if
      call createParticleConfig(P_nu_eAnti, P_tauMinus, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1208
      if ( res /= 1208) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",585
      if ( res /= 585) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",55
      if ( res /= 55) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_muMinus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",130
      if ( res /= 130) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GMinus, P_WPlus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1253
      if ( res /= 1253) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_nu_mu, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",435
      if ( res /= 435) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_nu_e, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",512
      if ( res /= 512) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",408
      if ( res /= 408) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_u, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",353
      if ( res /= 353) then
        stop
      end if
      call createParticleConfig(P_b, P_bAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",684
      if ( res /= 684) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_WpMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1005
      if ( res /= 1005) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1349
      if ( res /= 1349) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_GPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1280
      if ( res /= 1280) then
        stop
      end if
      call createParticleConfig(P_A, P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1245
      if ( res /= 1245) then
        stop
      end if
      call createParticleConfig(P_H, P_GPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",952
      if ( res /= 952) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",20
      if ( res /= 20) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_WPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",95
      if ( res /= 95) then
        stop
      end if
      call createParticleConfig(P_t, P_bAnti, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",441
      if ( res /= 441) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_b, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1375
      if ( res /= 1375) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_WPlus, P_ghAAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",833
      if ( res /= 833) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_ghWpAnti, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",719
      if ( res /= 719) then
        stop
      end if
      call createParticleConfig(P_nu_tauAnti, P_muMinus, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",632
      if ( res /= 632) then
        stop
      end if
      call createParticleConfig(P_Z, P_sAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",853
      if ( res /= 853) then
        stop
      end if
      call createParticleConfig(P_A, P_ghWp, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",54
      if ( res /= 54) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",481
      if ( res /= 481) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_s, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1156
      if ( res /= 1156) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghAAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1149
      if ( res /= 1149) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",11
      if ( res /= 11) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_A, P_GMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1323
      if ( res /= 1323) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",288
      if ( res /= 288) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_nu_muAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",73
      if ( res /= 73) then
        stop
      end if
      call createParticleConfig(P_G0, P_ghWmAnti, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",697
      if ( res /= 697) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_H, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1139
      if ( res /= 1139) then
        stop
      end if
      call createParticleConfig(P_s, P_uAnti, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",425
      if ( res /= 425) then
        stop
      end if
      call createParticleConfig(P_Z, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",920
      if ( res /= 920) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_GMinus, P_G0, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",764
      if ( res /= 764) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_Z, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",298
      if ( res /= 298) then
        stop
      end if
      call createParticleConfig(P_G0, P_G0, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",823
      if ( res /= 823) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_muPlus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",374
      if ( res /= 374) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_nu_eAnti, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",564
      if ( res /= 564) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_nu_muAnti, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1265
      if ( res /= 1265) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_nu_muAnti, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",867
      if ( res /= 867) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_GPlus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",583
      if ( res /= 583) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_WpPlus, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",940
      if ( res /= 940) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_H, P_A, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",707
      if ( res /= 707) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_WPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",393
      if ( res /= 393) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_Z, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",886
      if ( res /= 886) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_G0, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1301
      if ( res /= 1301) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_dAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",789
      if ( res /= 789) then
        stop
      end if
      call createParticleConfig(P_H, P_A, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",824
      if ( res /= 824) then
        stop
      end if
      call createParticleConfig(P_c, P_GMinus, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1057
      if ( res /= 1057) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_s, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",163
      if ( res /= 163) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1373
      if ( res /= 1373) then
        stop
      end if
      call createParticleConfig(P_H, P_eMinus, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",33
      if ( res /= 33) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1042
      if ( res /= 1042) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_H, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1215
      if ( res /= 1215) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_d, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",491
      if ( res /= 491) then
        stop
      end if
      call createParticleConfig(P_G0, P_GMinus, P_G0, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",915
      if ( res /= 915) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_H, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",617
      if ( res /= 617) then
        stop
      end if
      call createParticleConfig(P_g, P_s, P_sAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",409
      if ( res /= 409) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghWmAnti, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",576
      if ( res /= 576) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_G0, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",941
      if ( res /= 941) then
        stop
      end if
      call createParticleConfig(P_H, P_A, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",964
      if ( res /= 964) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_A, P_H, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",363
      if ( res /= 363) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1231
      if ( res /= 1231) then
        stop
      end if
      call createParticleConfig(P_G0, P_WMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",815
      if ( res /= 815) then
        stop
      end if
      call createParticleConfig(P_c, P_A, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",476
      if ( res /= 476) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_A, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",116
      if ( res /= 116) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_Z, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",248
      if ( res /= 248) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_Z, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",703
      if ( res /= 703) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_Z, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",547
      if ( res /= 547) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_ePlus, P_nu_mu, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",450
      if ( res /= 450) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_G0, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",478
      if ( res /= 478) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_GPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",399
      if ( res /= 399) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_A, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1274
      if ( res /= 1274) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_WPlus, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",521
      if ( res /= 521) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1352
      if ( res /= 1352) then
        stop
      end if
      call createParticleConfig(P_A, P_GPlus, P_A, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",751
      if ( res /= 751) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_ghWpAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1198
      if ( res /= 1198) then
        stop
      end if
      call createParticleConfig(P_ghA, P_ghWmAnti, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",989
      if ( res /= 989) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_WpPlus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",417
      if ( res /= 417) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_nu_e, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",59
      if ( res /= 59) then
        stop
      end if
      call createParticleConfig(P_t, P_tAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",786
      if ( res /= 786) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_g, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1399
      if ( res /= 1399) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_GMinus, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",232
      if ( res /= 232) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_muPlus, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",68
      if ( res /= 68) then
        stop
      end if
      call createParticleConfig(P_nu_tau, P_tauPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",146
      if ( res /= 146) then
        stop
      end if
      call createParticleConfig(P_s, P_g, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1422
      if ( res /= 1422) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_WPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",332
      if ( res /= 332) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",203
      if ( res /= 203) then
        stop
      end if
      call createParticleConfig(P_Z, P_nu_e, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",828
      if ( res /= 828) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_WMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1136
      if ( res /= 1136) then
        stop
      end if
      call createParticleConfig(P_A, P_muMinus, P_muPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1196
      if ( res /= 1196) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WMinus, P_GPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1302
      if ( res /= 1302) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_u, P_WpMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",832
      if ( res /= 832) then
        stop
      end if
      call createParticleConfig(P_H, P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",543
      if ( res /= 543) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_WPlus, P_A, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1168
      if ( res /= 1168) then
        stop
      end if
      call createParticleConfig(P_g, P_b, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1424
      if ( res /= 1424) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_Z, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",960
      if ( res /= 960) then
        stop
      end if
      call createParticleConfig(P_u, P_WpMinus, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",135
      if ( res /= 135) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_s, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",721
      if ( res /= 721) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_WpPlus, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",290
      if ( res /= 290) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_ghZ, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1125
      if ( res /= 1125) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_Z, P_nu_eAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1128
      if ( res /= 1128) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_u, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1060
      if ( res /= 1060) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_d, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",219
      if ( res /= 219) then
        stop
      end if
      call createParticleConfig(P_s, P_sAnti, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",756
      if ( res /= 756) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_c, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1421
      if ( res /= 1421) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_H, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",102
      if ( res /= 102) then
        stop
      end if
      call createParticleConfig(P_d, P_g, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1446
      if ( res /= 1446) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_H, P_Z, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1049
      if ( res /= 1049) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_s, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1420
      if ( res /= 1420) then
        stop
      end if
      call createParticleConfig(P_H, P_WPlus, P_Z, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1210
      if ( res /= 1210) then
        stop
      end if
      call createParticleConfig(P_u, P_WpMinus, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1163
      if ( res /= 1163) then
        stop
      end if
      call createParticleConfig(P_ghZAnti, P_GPlus, P_ghWm, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",198
      if ( res /= 198) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_H, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",389
      if ( res /= 389) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_nu_eAnti, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",912
      if ( res /= 912) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_H, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",93
      if ( res /= 93) then
        stop
      end if
      call createParticleConfig(P_nu_muAnti, P_WPlus, P_muMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",539
      if ( res /= 539) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_A, P_WMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",427
      if ( res /= 427) then
        stop
      end if
      call createParticleConfig(P_Z, P_t, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",692
      if ( res /= 692) then
        stop
      end if
      call createParticleConfig(P_nu_e, P_ePlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",266
      if ( res /= 266) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_WpPlus, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1241
      if ( res /= 1241) then
        stop
      end if
      call createParticleConfig(P_Z, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",201
      if ( res /= 201) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_b, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",967
      if ( res /= 967) then
        stop
      end if
      call createParticleConfig(P_H, P_GPlus, P_H, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",889
      if ( res /= 889) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_G0, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",687
      if ( res /= 687) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_nu_tau, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1165
      if ( res /= 1165) then
        stop
      end if
      call createParticleConfig(P_b, P_g, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",722
      if ( res /= 722) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_G0, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",431
      if ( res /= 431) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_H, P_WMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",553
      if ( res /= 553) then
        stop
      end if
      call createParticleConfig(P_ghA, P_GMinus, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",574
      if ( res /= 574) then
        stop
      end if
      call createParticleConfig(P_ePlus, P_G0, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",241
      if ( res /= 241) then
        stop
      end if
      call createParticleConfig(P_H, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1019
      if ( res /= 1019) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_WpMinus, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",509
      if ( res /= 509) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_ghWmAnti, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1235
      if ( res /= 1235) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_tauPlus, P_nu_tau, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",780
      if ( res /= 780) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_nu_tauAnti, P_tauMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",117
      if ( res /= 117) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_b, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",587
      if ( res /= 587) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_d, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",643
      if ( res /= 643) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_muMinus, P_nu_tauAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",900
      if ( res /= 900) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_A, P_Z, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",911
      if ( res /= 911) then
        stop
      end if
      call createParticleConfig(P_ghWmAnti, P_GMinus, P_ghZ, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1027
      if ( res /= 1027) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_tauMinus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1002
      if ( res /= 1002) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_H, P_WPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1266
      if ( res /= 1266) then
        stop
      end if
      call createParticleConfig(P_H, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",498
      if ( res /= 498) then
        stop
      end if
      call createParticleConfig(P_sAnti, P_g, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1405
      if ( res /= 1405) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_G0, P_GMinus, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",676
      if ( res /= 676) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_d, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1205
      if ( res /= 1205) then
        stop
      end if
      call createParticleConfig(P_muPlus, P_muMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",91
      if ( res /= 91) then
        stop
      end if
      call createParticleConfig(P_ghWpAnti, P_G0, P_ghWp, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",665
      if ( res /= 665) then
        stop
      end if
      call createParticleConfig(P_H, P_c, P_cAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",339
      if ( res /= 339) then
        stop
      end if
      call createParticleConfig(P_g, P_sAnti, P_b, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1439
      if ( res /= 1439) then
        stop
      end if
      call createParticleConfig(P_Z, P_G0, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",242
      if ( res /= 242) then
        stop
      end if
      call createParticleConfig(P_g, P_dAnti, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",544
      if ( res /= 544) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_g, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1393
      if ( res /= 1393) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_t, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",685
      if ( res /= 685) then
        stop
      end if
      call createParticleConfig(P_bAnti, P_b, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1154
      if ( res /= 1154) then
        stop
      end if
      call createParticleConfig(P_d, P_Z, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",122
      if ( res /= 122) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",174
      if ( res /= 174) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_A, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",871
      if ( res /= 871) then
        stop
      end if
      call createParticleConfig(P_Z, P_Z, P_WMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1303
      if ( res /= 1303) then
        stop
      end if
      call createParticleConfig(P_t, P_A, P_tAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",622
      if ( res /= 622) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_H, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1069
      if ( res /= 1069) then
        stop
      end if
      call createParticleConfig(P_G0, P_Z, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1246
      if ( res /= 1246) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",829
      if ( res /= 829) then
        stop
      end if
      call createParticleConfig(P_uAnti, P_u, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1152
      if ( res /= 1152) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_sAnti, P_c, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",638
      if ( res /= 638) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_H, P_ghZAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",754
      if ( res /= 754) then
        stop
      end if
      call createParticleConfig(P_A, P_tauMinus, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",709
      if ( res /= 709) then
        stop
      end if
      call createParticleConfig(P_b, P_WpPlus, P_uAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",822
      if ( res /= 822) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_Z, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",606
      if ( res /= 606) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_GPlus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1212
      if ( res /= 1212) then
        stop
      end if
      call createParticleConfig(P_A, P_G0, P_GMinus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",980
      if ( res /= 980) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_nu_e, P_tauPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",566
      if ( res /= 566) then
        stop
      end if
      call createParticleConfig(P_H, P_H, P_WPlus, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",654
      if ( res /= 654) then
        stop
      end if
      call createParticleConfig(P_G0, P_WPlus, P_GMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",958
      if ( res /= 958) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_G0, P_GPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1239
      if ( res /= 1239) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_u, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1386
      if ( res /= 1386) then
        stop
      end if
      call createParticleConfig(P_dAnti, P_G0, P_d, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",852
      if ( res /= 852) then
        stop
      end if
      call createParticleConfig(P_tauPlus, P_tauMinus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",245
      if ( res /= 245) then
        stop
      end if
      call createParticleConfig(P_A, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1340
      if ( res /= 1340) then
        stop
      end if
      call createParticleConfig(P_g, P_ghGAnti, P_ghG, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",711
      if ( res /= 711) then
        stop
      end if
      call createParticleConfig(P_ghWm, P_G0, P_ghWmAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",392
      if ( res /= 392) then
        stop
      end if
      call createParticleConfig(P_muMinus, P_muPlus, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",640
      if ( res /= 640) then
        stop
      end if
      call createParticleConfig(P_eMinus, P_Z, P_ePlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",820
      if ( res /= 820) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_cAnti, P_s, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",199
      if ( res /= 199) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_d, P_WpPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",337
      if ( res /= 337) then
        stop
      end if
      call createParticleConfig(P_cAnti, P_c, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",909
      if ( res /= 909) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_GMinus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",264
      if ( res /= 264) then
        stop
      end if
      call createParticleConfig(P_tAnti, P_g, P_t, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",32
      if ( res /= 32) then
        stop
      end if
      call createParticleConfig(P_t, P_WpMinus, P_bAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",209
      if ( res /= 209) then
        stop
      end if
      call createParticleConfig(P_GMinus, P_Z, P_G0, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1034
      if ( res /= 1034) then
        stop
      end if
      call createParticleConfig(P_WpMinus, P_c, P_dAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",993
      if ( res /= 993) then
        stop
      end if
      call createParticleConfig(P_ghZ, P_GPlus, P_ghWpAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1260
      if ( res /= 1260) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WMinus, P_WPlus, P_WPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",906
      if ( res /= 906) then
        stop
      end if
      call createParticleConfig(P_u, P_uAnti, P_A, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1328
      if ( res /= 1328) then
        stop
      end if
      call createParticleConfig(P_A, P_WMinus, P_GPlus, P_H, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",136
      if ( res /= 136) then
        stop
      end if
      call createParticleConfig(P_A, P_Z, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1058
      if ( res /= 1058) then
        stop
      end if
      call createParticleConfig(P_GPlus, P_WMinus, P_G0, P_Z, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",774
      if ( res /= 774) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_sAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",607
      if ( res /= 607) then
        stop
      end if
      call createParticleConfig(P_A, P_WPlus, P_A, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1226
      if ( res /= 1226) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_Z, P_GMinus, P_G0, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1157
      if ( res /= 1157) then
        stop
      end if
      call createParticleConfig(P_WPlus, P_H, P_WMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",620
      if ( res /= 620) then
        stop
      end if
      call createParticleConfig(P_g, P_cAnti, P_u, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1426
      if ( res /= 1426) then
        stop
      end if
      call createParticleConfig(P_Z, P_WMinus, P_H, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1029
      if ( res /= 1029) then
        stop
      end if
      call createParticleConfig(P_G0, P_ePlus, P_eMinus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1217
      if ( res /= 1217) then
        stop
      end if
      call createParticleConfig(P_t, P_cAnti, P_g, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",1411
      if ( res /= 1411) then
        stop
      end if
      call createParticleConfig(P_WpPlus, P_eMinus, P_nu_muAnti, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",243
      if ( res /= 243) then
        stop
      end if
      call createParticleConfig(P_WMinus, P_WPlus, P_GMinus, P_GPlus, config)
      call dict(config, 1, address, found, 0)
      res = dict_get_value(address)
      write (*,*) "out=", res, found, address, "shouldbe = ",469
      if ( res /= 469) then
        stop
      end if
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(9)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(13)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(14)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(15)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(16)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(17)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(18)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(20)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(21)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(22)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(26)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(27)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(28)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(41)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(42)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(43)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(44)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(45)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(46)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(47)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(49)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(50)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(51)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(52)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(55)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(59)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(62)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(65)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(66)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(68)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
